(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    152905,       3814]*)
(*NotebookOutlinePosition[    206487,       5526]*)
(*  CellTagsIndexPosition[    206443,       5522]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Prove the equivalence between the nomenclature in the thesis and in \
the notebook which produced the plots in the thesis\
\>", "Subtitle"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Off", "[", 
        RowBox[{"General", "::", "spell"}], "]"}], ";"}]], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{"Needs", "[", "\"\<Utilities`Notation`\>\"", "]"}], ";", 
      RowBox[{"<<", "Graphics`Colors`"}], ";"}]], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
Warning, sometimes the following needs to be evaluated twice or \
more to really be used in the verification cells below.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Map", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"SetOptions", "[", 
              RowBox[{"#", ",", 
                RowBox[{"Assumptions", "->", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SubscriptBox["\[Sigma]", "p"], ">", "0"}], ",", 
                      RowBox[{
                        SubscriptBox["\[Sigma]", "x"], ">", "0"}], ",", 
                      RowBox[{"m", ">", "0"}], ",", 
                      RowBox[{"T", ">", "0"}], ",", 
                      RowBox[{"\[Tau]", ">", "0"}], ",", 
                      RowBox[{
                        SubscriptBox["p", "g"], ">", "0"}]}], "}"}]}]}], 
              "]"}], "&"}], ",", " ", 
          RowBox[{"{", 
            RowBox[{
            "Simplify", ",", "FullSimplify", ",", "Integrate", ",", "Series", 
              ",", "Limit"}], "}"}]}], "]"}], ";", 
      RowBox[{"Symbolize", "[", 
        TagBox[
          SubscriptBox["_", "_"],
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], "]"}], ";"}]], "Input",
  CellLabel->"In[159]:="],

Cell[BoxData[{
    RowBox[{
      RowBox[{"h", "=", 
        RowBox[{"2", 
          SubscriptBox["\[Sigma]", "x"], " ", 
          SubscriptBox["\[Sigma]", "p"]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        SubscriptBox["l", "pt"], "=", 
        FractionBox[
          RowBox[{"\[Tau]", " ", 
            SubscriptBox["p", "g"]}], 
          RowBox[{"2", " ", "m"}]]}], ";"}]}], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
          "The", " ", "following", " ", "convention", " ", "will", " ", "be", 
            " ", 
            RowBox[{"followed", ":", " ", 
              RowBox[{
              "j", " ", "indexes", " ", "are", " ", "explicitly", " ", 
                "incorporated", " ", "into", " ", "the", " ", 
                "subindexes"}]}]}], ";", " ", 
          RowBox[{"i", "-", 
            RowBox[{
            "indexed", " ", "variables", " ", "are", " ", "themselves", " ", 
              RowBox[{"arrays", "."}]}]}]}]}], TraditionalForm]]]], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"k", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"1", "-", "P"}], ")"}], "2"], "/", "4"}], ",", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"1", "+", "P"}], ")"}], "2"], "/", "4"}], ",", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  SuperscriptBox["P", "2"]}], ")"}], "/", "2"}]}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"l", "=", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "L"}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        SubscriptBox["x", "i"], "=", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"c", "+", "L"}], ",", 
              RowBox[{"c", "-", "L"}], ",", "c"}], "}"}], "-", 
          SubscriptBox["x", "g"]}]}], ";"}]}], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
Old expressions; kept for reference and automated comparison \
(below)\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"e", "=", 
        FractionBox["1", 
          RowBox[{"2", " ", 
            SuperscriptBox[
              SubscriptBox["\[Sigma]", "p"], "2"]}]]}], ";", 
      RowBox[{"f", "=", 
        FractionBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"T", "+", "\[Tau]"}], ")"}], "2"], 
          RowBox[{"2", " ", 
            SuperscriptBox[
              SubscriptBox["\[Sigma]", "x"], "2"], " ", 
            SuperscriptBox["m", "2"]}]]}], ";", 
      RowBox[{
        SubscriptBox["p", "1"], "=", 
        RowBox[{"m", 
          FractionBox[
            SubscriptBox["x", "i"], 
            RowBox[{"T", "+", "\[Tau]"}]]}]}], ";", 
      RowBox[{
        SubscriptBox["p", "2"], "=", 
        FractionBox[
          RowBox[{
            RowBox[{"e", " ", 
              SubscriptBox["p", "g"]}], "+", 
            RowBox[{"f", " ", 
              SubscriptBox["p", "1"]}]}], 
          RowBox[{"e", "+", "f"}]]}], ";", 
      RowBox[{"G", "=", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", 
            RowBox[{"2", " ", 
              RowBox[{"L", "/", "h"}]}]}], "}"}]}], ";", " ", 
      RowBox[{"x0cA", "=", 
        RowBox[{
          SubscriptBox["x", "g"], "-", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"c", "+", "L"}], ",", 
              RowBox[{"c", "-", "L"}], ",", "c"}], "}"}]}]}], ";", " ", 
      RowBox[{"oldearly", "=", 
        RowBox[{
          FractionBox[
            RowBox[{"k", " ", 
              SubscriptBox["p", "2"]}], 
            RowBox[{
              SqrtBox[
                RowBox[{"\[Pi]", " "}]], "m", " ", "h"}]], 
          RowBox[{"Exp", "[", 
            RowBox[{
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"e", " ", "f"}], 
                  RowBox[{"e", "+", "f"}]]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox["p", "g"], "-", 
                    SubscriptBox["p", "1"]}], ")"}], "2"]}], "]"}], 
          RowBox[{"Exp", "[", 
            RowBox[{"-", 
              FractionBox[
                SuperscriptBox["G", "2"], 
                RowBox[{"4", 
                  RowBox[{"(", 
                    RowBox[{"e", "+", "f"}], ")"}]}]]}], "]"}], "  ", 
          FractionBox[
            RowBox[{"Cos", "[", 
              RowBox[{"G", " ", 
                SubscriptBox["p", "2"]}], "]"}], 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"e", "+", "f"}], ")"}], 
              RowBox[{"1", "/", "2"}]]]}]}], ";", " ", 
      RowBox[{"oldlate", "=", 
        RowBox[{"oldearly", "/.", 
          RowBox[{"\[Tau]", "\[Rule]", "0"}]}]}], ";"}]], "Input",
  CellLabel->"In[10]:="],

Cell["Old expressions used for the time interference components", "Text"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{"oldt", "=", 
          FractionBox[
            RowBox[{"T", "+", 
              RowBox[{"\[Tau]", "/", "2"}]}], 
            SubscriptBox["\[Zeta]", "\[Tau]2"]]}], ";", 
        RowBox[{"ee", "=", "e"}], ";", 
        RowBox[{"ff", "=", 
          FractionBox[
            SuperscriptBox["oldt", "2"], 
            RowBox[{"2", " ", 
              SuperscriptBox["m", "2"], 
              SuperscriptBox[
                SubscriptBox["\[Sigma]", "x"], "2"]}]]}], ";", 
        RowBox[{"Y", "=", 
          RowBox[{"ee", "+", "ff"}]}], ";", 
        RowBox[{"R", "=", 
          RowBox[{
            FractionBox[
              RowBox[{"2", "m"}], 
              RowBox[{"h", " ", "\[Tau]"}]], 
            SubscriptBox["\[Zeta]", "\[Tau]2"]}]}], ";", 
        RowBox[{"oldx", "=", 
          RowBox[{"-", 
            FractionBox[
              SubscriptBox["x", "i"], 
              RowBox[{
                SubscriptBox["\[Sigma]", "x"], " ", 
                SubscriptBox["\[Zeta]", "\[Tau]2"]}]]}]}], ";", 
        RowBox[{
          SubscriptBox["c", "0"], "=", 
          RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FractionBox["\[Tau]", 
                    RowBox[{"2", " ", 
                      SubscriptBox["t", "\[Zeta]"]}]], " ", 
                  SuperscriptBox["oldx", "2"]}], "+", 
                RowBox[{"ArcTan", "[", 
                  RowBox[{"2", 
                    RowBox[{
                      SubscriptBox["t", "\[Zeta]"], "/", "\[Tau]"}]}], "]"}], 
                "-", 
                RowBox[{"\[Pi]", "/", "2"}]}], ")"}]}]}], ";", 
        RowBox[{
          SubscriptBox["c", "1"], "=", 
          FractionBox[
            RowBox[{"\[Tau]", " ", "oldx", " ", "oldt"}], 
            RowBox[{"2", " ", 
              SubscriptBox["t", "\[Zeta]"], 
              SubscriptBox["\[Sigma]", "x"], " ", "m"}]]}], ";", 
        RowBox[{
          SubscriptBox["c", 
            RowBox[{"1", "+"}]], "=", 
          RowBox[{
            SubscriptBox["c", "1"], "+", "G"}]}], ";", 
        RowBox[{
          SubscriptBox["c", 
            RowBox[{"1", "-"}]], "=", 
          RowBox[{
            SubscriptBox["c", "1"], "-", "G"}]}], ";", 
        RowBox[{
          SubscriptBox["c", "2"], "=", 
          RowBox[{
            FractionBox["2", 
              RowBox[{"h", " ", "m", " ", "\[Tau]"}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      FractionBox["\[Tau]", 
                        RowBox[{"2", " ", 
                          SubscriptBox["t", "\[Zeta]"]}]], ")"}], "2"], 
                  SuperscriptBox["oldt", "2"]}], "-", 
                FractionBox[
                  SuperscriptBox["\[Tau]", "2"], "4"]}], ")"}]}]}], ";", 
        RowBox[{
          SubscriptBox["p", "3"], "=", 
          RowBox[{"m", 
            FractionBox[
              SubscriptBox["x", "i"], 
              RowBox[{"T", "+", 
                RowBox[{"\[Tau]", "/", "2"}]}]]}]}], ";", 
        RowBox[{
          SubscriptBox["p", "4"], "=", 
          FractionBox[
            RowBox[{
              RowBox[{"ee", " ", 
                SubscriptBox["p", "g"]}], "+", 
              RowBox[{"ff", " ", 
                SubscriptBox["p", "3"]}]}], "Y"]}], ";", 
        RowBox[{
          SubscriptBox["R", "t"], "=", 
          SqrtBox[
            RowBox[{
              SuperscriptBox[
                SubscriptBox["c", "2"], "2"], "+", 
              SuperscriptBox["Y", "2"]}]]}], ";", 
        RowBox[{"\[Gamma]", "=", 
          RowBox[{"ArcTan", "[", 
            FractionBox[
              SubscriptBox["c", "2"], "Y"], "]"}]}], ";"}]}]], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{"oldcomexp", "=", 
        RowBox[{"Exp", "[", 
          RowBox[{
            RowBox[{"-", 
              FractionBox[
                RowBox[{"ee", " ", "ff"}], "Y"]}], 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox["p", "g"], "-", 
                  SubscriptBox["p", "3"]}], ")"}], "2"]}], "]"}]}], ";", 
      RowBox[{"oldprefac", "=", 
        RowBox[{
          FractionBox["k", 
            RowBox[{" ", 
              SqrtBox[
                RowBox[{"2", " ", 
                  SuperscriptBox["h", "3"], " ", "\[Pi]", " ", "m", " ", 
                  "\[Tau]"}]]}]], " ", 
          FractionBox[
            SubscriptBox["p", "4"], 
            SqrtBox[
              RowBox[{"R", " ", 
                SubscriptBox["R", "t"]}]]]}]}], ";", 
      RowBox[{"oldexpplusl", "=", 
        RowBox[{"Exp", "[", 
          RowBox[{"-", 
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox["c", 
                        RowBox[{"1", "+"}]], "+", 
                      RowBox[{"2", " ", 
                        SubscriptBox["c", "2"], " ", 
                        SubscriptBox["p", "4"]}]}], ")"}], "2"], "Y"}], 
              RowBox[{"4", " ", 
                SuperscriptBox[
                  SubscriptBox["R", "t"], "2"]}]]}], "]"}]}], ";", 
      RowBox[{"oldexpminusl", "=", 
        RowBox[{"Exp", "[", 
          RowBox[{"-", 
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox["c", 
                        RowBox[{"1", "-"}]], "+", 
                      RowBox[{"2", " ", 
                        SubscriptBox["c", "2"], " ", 
                        SubscriptBox["p", "4"]}]}], ")"}], "2"], "Y"}], 
              RowBox[{"4", " ", 
                SuperscriptBox[
                  SubscriptBox["R", "t"], "2"]}]]}], "]"}]}], ";", 
      RowBox[{"oldcosplusl", "=", 
        RowBox[{"Cos", "[", 
          RowBox[{
            RowBox[{
              FractionBox["1", 
                SuperscriptBox[
                  SubscriptBox["R", "t"], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SubscriptBox["p", "4"], " ", 
                    SuperscriptBox["Y", "2"], 
                    RowBox[{"(", 
                      RowBox[{
                        SubscriptBox["c", 
                          RowBox[{"1", "+"}]], "+", 
                        RowBox[{
                          SubscriptBox["c", "2"], " ", 
                          SubscriptBox["p", "4"]}]}], ")"}]}], "-", 
                  RowBox[{
                    SubscriptBox["c", "2"], " ", 
                    RowBox[{
                      SuperscriptBox[
                        SubscriptBox["c", 
                          RowBox[{"1", "+"}]], "2"], "/", "4"}]}]}], ")"}]}], 
            "+", 
            SubscriptBox["c", "0"], "+", 
            FractionBox["\[Gamma]", "2"]}], "]"}]}], ";", 
      RowBox[{"oldcosminusl", "=", 
        RowBox[{"Cos", "[", 
          RowBox[{
            RowBox[{
              FractionBox["1", 
                SuperscriptBox[
                  SubscriptBox["R", "t"], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SubscriptBox["p", "4"], 
                    SuperscriptBox["Y", "2"], 
                    RowBox[{"(", 
                      RowBox[{
                        SubscriptBox["c", 
                          RowBox[{"1", "-"}]], "+", 
                        RowBox[{
                          SubscriptBox["c", "2"], " ", 
                          SubscriptBox["p", "4"]}]}], ")"}]}], "-", 
                  RowBox[{
                    SubscriptBox["c", "2"], " ", 
                    RowBox[{
                      SuperscriptBox[
                        SubscriptBox["c", 
                          RowBox[{"1", "-"}]], "2"], "/", "4"}]}]}], ")"}]}], 
            "+", 
            SubscriptBox["c", "0"], "+", 
            FractionBox["\[Gamma]", "2"]}], "]"}]}], ";"}]], "Input",
  CellLabel->"In[12]:="],

Cell[TextData[StyleBox["New expressions:", "Section"]], "Text"],

Cell["Some times", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SubscriptBox["t", "2"], "=", 
        RowBox[{"T", "+", "\[Tau]"}]}], ";", 
      RowBox[{
        SubscriptBox["t", "3"], "=", 
        RowBox[{"T", "+", 
          RowBox[{"\[Tau]", "/", "2"}]}]}], ";", 
      RowBox[{
        SubscriptBox["t", "\[Sigma]"], "=", 
        FractionBox[
          RowBox[{"m", " ", 
            SubscriptBox["\[Sigma]", "x"]}], 
          SubscriptBox["p", "g"]]}], ";", 
      RowBox[{
        SubscriptBox["t", "i"], "=", 
        RowBox[{"m", " ", 
          FractionBox[
            SubscriptBox["x", "i"], 
            SubscriptBox["p", "g"]]}]}], ";", 
      RowBox[{
        SubscriptBox["t", "\[Zeta]"], "=", 
        RowBox[{"m", " ", 
          FractionBox[
            SubscriptBox["\[Sigma]", "x"], 
            SubscriptBox["\[Sigma]", "p"]]}]}], ";", 
      RowBox[{
        SubscriptBox["t\[Prime]", "\[Zeta]"], "=", 
        SqrtBox[
          RowBox[{
            SuperscriptBox[
              SubscriptBox["t", "\[Zeta]"], "2"], "+", 
            SuperscriptBox[
              RowBox[{"(", 
                FractionBox["\[Tau]", "2"], ")"}], "2"]}]]}], ";", 
      RowBox[{
        SubscriptBox["t", "s"], "=", 
        RowBox[{"m", 
          FractionBox[
            RowBox[{"c", "-", 
              SubscriptBox["x", "g"]}], 
            SubscriptBox["p", "g"]]}]}], ";", 
      RowBox[{
        SubscriptBox["t", "pt"], "=", 
        RowBox[{
          SubscriptBox["t", "s"], "-", 
          FractionBox["\[Tau]", "2"]}]}], ";"}]], "Input",
  CellLabel->"In[13]:="],

Cell["Some broadenings", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"\[Zeta]", "=", 
        SqrtBox[
          RowBox[{"1", "+", 
            RowBox[{
              SuperscriptBox["tt", "2"], "/", 
              SuperscriptBox[
                SubscriptBox["t", "\[Zeta]"], "2"]}]}]]}], ";", 
      RowBox[{"\[Zeta]\[Prime]", "=", 
        SqrtBox[
          RowBox[{"1", "+", 
            FractionBox[
              SuperscriptBox["tt", "2"], 
              SuperscriptBox[
                SubscriptBox["t\[Prime]", "\[Zeta]"], "2"]]}]]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        SubscriptBox["\[Zeta]", "2"], "=", 
        RowBox[{"\[Zeta]", "/.", 
          RowBox[{"tt", "->", 
            SubscriptBox["t", "2"]}]}]}], ";", 
      RowBox[{
        SubscriptBox["\[Zeta]", "\[Tau]2"], "=", 
        RowBox[{"\[Zeta]", "/.", 
          RowBox[{"tt", "\[Rule]", 
            FractionBox["\[Tau]", "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox["\[Zeta]", "1"], "=", 
          RowBox[{"\[Zeta]", "/.", 
            RowBox[{"tt", "->", "T"}]}]}], ";", 
        RowBox[{
          SubscriptBox["\[Zeta]", "3"], "=", 
          RowBox[{"\[Zeta]", "/.", 
            RowBox[{"tt", "->", 
              SubscriptBox["t", "3"]}]}]}], " ", 
        RowBox[{"(*", 
          RowBox[{
            RowBox[{
            "these", " ", "two", " ", "not", " ", "directly", " ", "used", 
              " ", "in", " ", "the", " ", "expressions"}], ",", " ", 
            RowBox[{"but", " ", "for", " ", "comparison", " ", "purposes"}]}],
           "*)"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        SubscriptBox["\[Zeta]\[Prime]", "3"], "=", 
        RowBox[{"\[Zeta]\[Prime]", "/.", 
          RowBox[{"tt", "\[Rule]", 
            SubscriptBox["t", "3"]}]}]}], ";"}]}], "Input",
  CellLabel->"In[128]:="],

Cell["Some momenta", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SubscriptBox["p", "c2"], "=", 
        FractionBox[
          RowBox[{"m", " ", 
            SubscriptBox["x", "i"]}], 
          SubscriptBox["t", "2"]]}], ";", 
      RowBox[{
        SubscriptBox["p", "c3"], "=", 
        FractionBox[
          RowBox[{"m", " ", 
            SubscriptBox["x", "i"]}], 
          SubscriptBox["t", "3"]]}], ";", 
      RowBox[{
        SubscriptBox["p", "cb"], "=", 
        RowBox[{
          FractionBox["1", 
            SuperscriptBox[
              SubscriptBox["\[Zeta]", "2"], "2"]], 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["p", "g"], "+", 
              RowBox[{
                SubscriptBox["p", "c2"], 
                FractionBox[
                  SuperscriptBox[
                    SubscriptBox["t", "2"], "2"], 
                  SuperscriptBox[
                    SubscriptBox["t", "\[Zeta]"], "2"]]}]}], ")"}]}]}], ";", 
      RowBox[{
        SubscriptBox["p", "\[Sigma]2"], "=", 
        FractionBox[
          RowBox[{" ", 
            RowBox[{"m", " ", 
              SubscriptBox["\[Sigma]", "x"]}]}], 
          SubscriptBox["t", "2"]]}], ";", 
      RowBox[{
        SubscriptBox["p", "ct"], "=", 
        RowBox[{
          FractionBox["1", 
            SuperscriptBox[
              SubscriptBox["\[Zeta]\[Prime]", "3"], "2"]], 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["p", "g"], "+", 
              RowBox[{
                SubscriptBox["p", "c3"], 
                FractionBox[
                  SuperscriptBox[
                    SubscriptBox["t", "3"], "2"], 
                  SuperscriptBox[
                    SubscriptBox["t\[Prime]", "\[Zeta]"], "2"]]}]}], 
            ")"}]}]}], ";"}]], "Input",
  CellLabel->"In[17]:="],

Cell["Some dimensionless, auxiliary variables", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"u", "=", 
        RowBox[{
          FractionBox[
            RowBox[{"\[Tau]", "/", "2"}], 
            SubscriptBox["t", "\[Zeta]"]], 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                SuperscriptBox[
                  SubscriptBox["t", "3"], "2"], 
                SuperscriptBox[
                  SubscriptBox["t\[Prime]", "\[Zeta]"], "2"]], "-", "1"}], 
            ")"}]}]}], ";", 
      RowBox[{"u\[Prime]", "=", 
        SqrtBox[
          RowBox[{
            SuperscriptBox["u", "2"], "+", 
            SuperscriptBox[
              SubscriptBox["\[Zeta]\[Prime]", "3"], "4"]}]]}], ";", 
      RowBox[{
        SubscriptBox["v", "+"], "=", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              FractionBox["1", 
                SuperscriptBox[
                  SubscriptBox["\[Zeta]", "\[Tau]2"], "2"]]}], 
            FractionBox[
              RowBox[{
                SubscriptBox["t", "3"], 
                RowBox[{"\[Tau]", "/", "2"}]}], 
              SuperscriptBox[
                SubscriptBox["t", "\[Zeta]"], "2"]], 
            FractionBox[
              SubscriptBox["x", "i"], 
              SubscriptBox["\[Sigma]", "x"]]}], "+", 
          FractionBox["l", 
            SubscriptBox["\[Sigma]", "x"]]}]}], ";", 
      RowBox[{
        SubscriptBox["v", "-"], "=", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              FractionBox["1", 
                SuperscriptBox[
                  SubscriptBox["\[Zeta]", "\[Tau]2"], "2"]]}], 
            FractionBox[
              RowBox[{
                SubscriptBox["t", "3"], 
                RowBox[{"\[Tau]", "/", "2"}]}], 
              SuperscriptBox[
                SubscriptBox["t", "\[Zeta]"], "2"]], 
            FractionBox[
              SubscriptBox["x", "i"], 
              SubscriptBox["\[Sigma]", "x"]]}], "-", 
          FractionBox["l", 
            SubscriptBox["\[Sigma]", "x"]]}]}], ";", 
      RowBox[{
        SubscriptBox["\[Gamma]", "1"], "=", 
        RowBox[{
          FractionBox[
            RowBox[{
              SubscriptBox["t", "\[Zeta]"], 
              RowBox[{"\[Tau]", "/", "2"}]}], 
            RowBox[{"2", " ", 
              SuperscriptBox[
                SubscriptBox["\[Sigma]", "x"], "2"], 
              SuperscriptBox[
                SubscriptBox["t\[Prime]", "\[Zeta]"], "2"]}]], 
          SuperscriptBox[
            SubscriptBox["x", "i"], "2"]}]}], ";", 
      RowBox[{
        SubscriptBox["\[Gamma]", "2"], "=", 
        RowBox[{
          RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"ArcTan", "[", 
              FractionBox["u", 
                SuperscriptBox[
                  SubscriptBox["\[Zeta]\[Prime]", "3"], "2"]], "]"}]}], "+", 
          RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"ArcTan", "[", 
              FractionBox[
                SubscriptBox["t", "\[Zeta]"], 
                RowBox[{"\[Tau]", "/", "2"}]], "]"}]}]}]}], ";"}]], "Input",
  CellLabel->"In[18]:="],

Cell["\<\
Count rates in the new variables. As vectors, they contain three \
contributions: one from the short-arm, another from the long arm and a last \
one in behalf of path interference (centred around l=0).\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"CE", "=", 
        RowBox[{
          FractionBox["k", 
            SqrtBox[
              RowBox[{"2", "\[Pi]"}]]], 
          FractionBox[
            SubscriptBox["p", "cb"], 
            RowBox[{"m", " ", 
              SubscriptBox["\[Sigma]", "x"], 
              SubscriptBox["\[Zeta]", "2"]}]], 
          RowBox[{"Exp", "[", 
            FractionBox[
              RowBox[{"-", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox["t", "2"], "-", 
                      SubscriptBox["t", "i"]}], ")"}], "2"]}], 
              RowBox[{"2", " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["t", "\[Sigma]"], ")"}], "2"], 
                SuperscriptBox[
                  SubscriptBox["\[Zeta]", "2"], "2"]}]], "]"}], 
          RowBox[{"Exp", "[", 
            FractionBox[
              RowBox[{"-", 
                SuperscriptBox["l", "2"]}], 
              RowBox[{"2", " ", 
                SuperscriptBox[
                  SubscriptBox["\[Sigma]", "x"], "2"], 
                SuperscriptBox[
                  SubscriptBox["\[Zeta]", "2"], "2"]}]], "]"}], 
          RowBox[{"Cos", "[", 
            RowBox[{"2", " ", 
              SubscriptBox["p", "cb"], " ", 
              RowBox[{"l", "/", "h"}]}], "]"}]}]}], " ", 
      RowBox[{"(*", 
        RowBox[{"this", " ", "is", " ", 
          SubscriptBox["C", "2"], " ", "in", " ", "the", " ", "nomenclature", 
          " ", "of", " ", "the", " ", "DT"}], "*)"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"CL", "=", 
        RowBox[{"CE", "/.", 
          RowBox[{"\[Tau]", "\[Rule]", "0"}]}]}], "   ", 
      RowBox[{"(*", 
        RowBox[{"this", " ", "is", " ", 
          SubscriptBox["C", "1"]}], "*)"}], ";"}]}], "Input",
  CellLabel->"In[19]:="],

Cell["\<\
Showing equalities between old and new expressions for the early \
and late contributions. The two last ones are the equalities of the count \
rates themselves. Some of these simplifications will only succeed if \
appropriate assumptions are taken about the real and positive character of \
some variables.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Map", "[", 
      RowBox[{"Simplify", ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"-", "x0cA"}], ")"}], "-", 
              SubscriptBox["x", "i"]}], ",", 
            RowBox[{
              SubscriptBox["p", "1"], "-", 
              SubscriptBox["p", "c2"]}], ",", 
            RowBox[{
              SubscriptBox["p", "2"], "-", 
              SubscriptBox["p", "cb"]}], ",", 
            RowBox[{
              FractionBox[
                RowBox[{"e", " ", "f"}], 
                RowBox[{"e", "+", "f"}]], "-", 
              FractionBox["1", 
                RowBox[{"2", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      SubscriptBox["p", "\[Sigma]2"], ")"}], "2"], 
                  SuperscriptBox[
                    SubscriptBox["\[Zeta]", "2"], "2"]}]]}], ",", 
            RowBox[{
              FractionBox[
                RowBox[{"e", " ", "f", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        SubscriptBox["p", "g"], "-", 
                        SubscriptBox["p", "1"]}], ")"}], "2"]}], 
                RowBox[{"e", "+", "f"}]], "-", 
              FractionBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox["t", "2"], "-", 
                      SubscriptBox["t", "i"]}], ")"}], "2"], 
                RowBox[{"2", " ", 
                  SuperscriptBox[
                    SubscriptBox["t", "\[Sigma]"], "2"], 
                  SuperscriptBox[
                    SubscriptBox["\[Zeta]", "2"], "2"]}]]}], ",", 
            RowBox[{
              FractionBox["1", 
                SqrtBox[
                  RowBox[{"e", "+", "f"}]]], "-", 
              FractionBox[
                RowBox[{
                  SqrtBox["2"], 
                  SubscriptBox["\[Sigma]", "p"]}], 
                SubscriptBox["\[Zeta]", "2"]]}], ",", 
            RowBox[{"CE", "-", "oldearly"}], ",", 
            RowBox[{"CL", "-", "oldlate"}]}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "0", ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                FractionBox[
                  SubscriptBox["\[Sigma]", "p"], 
                  SqrtBox[
                    RowBox[{"1", "+", 
                      FractionBox[
                        RowBox[{
                          SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"T", "+", "\[Tau]"}], ")"}], "2"]}], 
                        RowBox[{
                          SuperscriptBox["m", "2"], " ", 
                          SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]]]}], 
              "+", 
              FractionBox["1", 
                SqrtBox[
                  FractionBox[
                    RowBox[{"1", "+", 
                      FractionBox[
                        RowBox[{
                          SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"T", "+", "\[Tau]"}], ")"}], "2"]}], 
                        RowBox[{
                          SuperscriptBox["m", "2"], " ", 
                          SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                    SubsuperscriptBox["\[Sigma]", "p", "2"]]]]}], ")"}]}], 
        ",", 
        RowBox[{"{", 
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    FractionBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"-", "c"}], " ", "m"}], "-", 
                            RowBox[{"L", " ", "m"}], "+", 
                            RowBox[{
                              SubscriptBox["p", "g"], " ", "T"}], "+", 
                            RowBox[{"m", " ", 
                              SubscriptBox["x", "g"]}], "+", 
                            RowBox[{
                              SubscriptBox["p", "g"], " ", "\[Tau]"}]}], 
                          ")"}], "2"], 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              SuperscriptBox["T", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                            
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}], "+", 
                            
                            RowBox[{"2", " ", "T", " ", 
                              SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                              "\[Tau]"}], "+", 
                            RowBox[{
                              SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], 
                " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "P"}], ")"}], "2"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        SubscriptBox["p", "g"], "+", 
                        FractionBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{"c", "+", "L", "-", 
                                SubscriptBox["x", "g"]}], ")"}], " ", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                            RowBox[{"(", 
                              RowBox[{"T", "+", "\[Tau]"}], ")"}]}], 
                          RowBox[{"m", " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"1", "+", 
                            FractionBox[
                              RowBox[{
                                SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                                
                                SuperscriptBox[
                                  RowBox[{"(", 
                                    RowBox[{"T", "+", "\[Tau]"}], ")"}], 
                                  "2"]}], 
                              RowBox[{
                                SuperscriptBox["m", "2"], " ", 
                                SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                          ")"}], 
                        RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                      RowBox[{
                        FractionBox[
                          SubscriptBox["p", "g"], 
                          SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                        FractionBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{"c", "+", "L", "-", 
                                SubscriptBox["x", "g"]}], ")"}], " ", 
                            RowBox[{"(", 
                              RowBox[{"T", "+", "\[Tau]"}], ")"}]}], 
                          RowBox[{"m", " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                      RowBox[{
                        SubscriptBox["\[Sigma]", "p"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FractionBox[
                              RowBox[{"1", "+", 
                                FractionBox[
                                  RowBox[{
                                    SubsuperscriptBox["\[Sigma]", "p", "2"], 
                                    " ", 
                                    SuperscriptBox[
                                      RowBox[{"(", 
                                        RowBox[{"T", "+", "\[Tau]"}], ")"}], 
                                      "2"]}], 
                                  RowBox[{
                                    SuperscriptBox["m", "2"], " ", 
                                    
                                    SubsuperscriptBox["\[Sigma]", "x", 
                                      "2"]}]]}], 
                              SubsuperscriptBox["\[Sigma]", "p", "2"]], ")"}],
                           
                          RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], 
              RowBox[{"4", " ", "m", " ", 
                SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]], " ", 
                SubscriptBox["\[Sigma]", "x"]}]], ",", 
            FractionBox[
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    FractionBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"-", "c"}], " ", "m"}], "+", 
                            RowBox[{"L", " ", "m"}], "+", 
                            RowBox[{
                              SubscriptBox["p", "g"], " ", "T"}], "+", 
                            RowBox[{"m", " ", 
                              SubscriptBox["x", "g"]}], "+", 
                            RowBox[{
                              SubscriptBox["p", "g"], " ", "\[Tau]"}]}], 
                          ")"}], "2"], 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              SuperscriptBox["T", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                            
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}], "+", 
                            
                            RowBox[{"2", " ", "T", " ", 
                              SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                              "\[Tau]"}], "+", 
                            RowBox[{
                              SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], 
                " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"1", "+", "P"}], ")"}], "2"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        SubscriptBox["p", "g"], "+", 
                        FractionBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{"c", "-", "L", "-", 
                                SubscriptBox["x", "g"]}], ")"}], " ", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                            RowBox[{"(", 
                              RowBox[{"T", "+", "\[Tau]"}], ")"}]}], 
                          RowBox[{"m", " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"1", "+", 
                            FractionBox[
                              RowBox[{
                                SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                                
                                SuperscriptBox[
                                  RowBox[{"(", 
                                    RowBox[{"T", "+", "\[Tau]"}], ")"}], 
                                  "2"]}], 
                              RowBox[{
                                SuperscriptBox["m", "2"], " ", 
                                SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                          ")"}], 
                        RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                      RowBox[{
                        FractionBox[
                          SubscriptBox["p", "g"], 
                          SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                        FractionBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{"c", "-", "L", "-", 
                                SubscriptBox["x", "g"]}], ")"}], " ", 
                            RowBox[{"(", 
                              RowBox[{"T", "+", "\[Tau]"}], ")"}]}], 
                          RowBox[{"m", " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                      RowBox[{
                        SubscriptBox["\[Sigma]", "p"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FractionBox[
                              RowBox[{"1", "+", 
                                FractionBox[
                                  RowBox[{
                                    SubsuperscriptBox["\[Sigma]", "p", "2"], 
                                    " ", 
                                    SuperscriptBox[
                                      RowBox[{"(", 
                                        RowBox[{"T", "+", "\[Tau]"}], ")"}], 
                                      "2"]}], 
                                  RowBox[{
                                    SuperscriptBox["m", "2"], " ", 
                                    
                                    SubsuperscriptBox["\[Sigma]", "x", 
                                      "2"]}]]}], 
                              SubsuperscriptBox["\[Sigma]", "p", "2"]], ")"}],
                           
                          RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], 
              RowBox[{"4", " ", "m", " ", 
                SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]], " ", 
                SubscriptBox["\[Sigma]", "x"]}]], ",", 
            FractionBox[
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    FractionBox[
                      RowBox[{
                        RowBox[{
                          SuperscriptBox["c", "2"], " ", 
                          SuperscriptBox["m", "2"]}], "+", 
                        RowBox[{
                          SuperscriptBox["L", "2"], " ", 
                          SuperscriptBox["m", "2"]}], "-", 
                        RowBox[{"2", " ", "c", " ", "m", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"m", " ", 
                                SubscriptBox["x", "g"]}], "+", 
                              RowBox[{
                                SubscriptBox["p", "g"], " ", 
                                RowBox[{"(", 
                                  RowBox[{"T", "+", "\[Tau]"}], ")"}]}]}], 
                            ")"}]}], "+", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"m", " ", 
                                SubscriptBox["x", "g"]}], "+", 
                              RowBox[{
                                SubscriptBox["p", "g"], " ", 
                                RowBox[{"(", 
                                  RowBox[{"T", "+", "\[Tau]"}], ")"}]}]}], 
                            ")"}], "2"]}], 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              SuperscriptBox["T", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                            
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}], "+", 
                            
                            RowBox[{"2", " ", "T", " ", 
                              SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                              "\[Tau]"}], "+", 
                            RowBox[{
                              SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                              SuperscriptBox["\[Tau]", "2"]}]}], ")"}]}]]}]], 
                " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["P", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", "T"}], " ", 
                      SubscriptBox["x", "g"], " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                    RowBox[{"m", " ", 
                      SubscriptBox["p", "g"], " ", 
                      SubsuperscriptBox["\[Sigma]", "x", "2"]}], "-", 
                    RowBox[{
                      SubscriptBox["x", "g"], " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                      "\[Tau]"}], "+", 
                    RowBox[{"c", " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                      RowBox[{"(", 
                        RowBox[{"T", "+", "\[Tau]"}], ")"}]}]}], ")"}], " ", 
                SqrtBox[
                  RowBox[{"1", "+", 
                    FractionBox[
                      RowBox[{
                        SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"T", "+", "\[Tau]"}], ")"}], "2"]}], 
                      RowBox[{
                        SuperscriptBox["m", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    SqrtBox[
                      RowBox[{"1", "+", 
                        FractionBox[
                          RowBox[{
                            SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                            SuperscriptBox[
                              RowBox[{"(", 
                                RowBox[{"T", "+", "\[Tau]"}], ")"}], "2"]}], 
                          RowBox[{
                            SuperscriptBox["m", "2"], " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], 
                    "-", 
                    RowBox[{
                      SubscriptBox["\[Sigma]", "p"], " ", 
                      SqrtBox[
                        FractionBox[
                          RowBox[{"1", "+", 
                            FractionBox[
                              RowBox[{
                                SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                                
                                SuperscriptBox[
                                  RowBox[{"(", 
                                    RowBox[{"T", "+", "\[Tau]"}], ")"}], 
                                  "2"]}], 
                              RowBox[{
                                SuperscriptBox["m", "2"], " ", 
                                SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                          
                          SubsuperscriptBox["\[Sigma]", "p", "2"]]]}]}], 
                  ")"}], " ", 
                RowBox[{"Cos", "[", 
                  FractionBox[
                    RowBox[{"L", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          FractionBox[
                            SubscriptBox["p", "g"], 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                          FractionBox[
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{"c", "-", 
                                  SubscriptBox["x", "g"]}], ")"}], " ", 
                              RowBox[{"(", 
                                RowBox[{"T", "+", "\[Tau]"}], ")"}]}], 
                            RowBox[{"m", " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                        ")"}]}], 
                    RowBox[{
                      SubscriptBox["\[Sigma]", "p"], " ", 
                      SubscriptBox["\[Sigma]", "x"], " ", 
                      RowBox[{"(", 
                        RowBox[{
                          FractionBox["1", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                          FractionBox[
                            SuperscriptBox[
                              RowBox[{"(", 
                                RowBox[{"T", "+", "\[Tau]"}], ")"}], "2"], 
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                        ")"}]}]], "]"}]}], 
              RowBox[{"2", " ", 
                SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]], " ", 
                SubsuperscriptBox["\[Sigma]", "p", "3"], " ", 
                SubscriptBox["\[Sigma]", "x"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["T", "2"], " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                    RowBox[{
                      SuperscriptBox["m", "2"], " ", 
                      SubsuperscriptBox["\[Sigma]", "x", "2"]}], "+", 
                    RowBox[{"2", " ", "T", " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                      "\[Tau]"}], "+", 
                    RowBox[{
                      SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                      SuperscriptBox["\[Tau]", "2"]}]}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FractionBox[
                      RowBox[{"1", "+", 
                        FractionBox[
                          RowBox[{
                            SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                            SuperscriptBox[
                              RowBox[{"(", 
                                RowBox[{"T", "+", "\[Tau]"}], ")"}], "2"]}], 
                          RowBox[{
                            SuperscriptBox["m", "2"], " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]], ")"}], 
                  RowBox[{"3", "/", "2"}]]}]]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    FractionBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{"c", " ", "m"}], "+", 
                            RowBox[{"L", " ", "m"}], "-", 
                            RowBox[{
                              SubscriptBox["p", "g"], " ", "T"}], "-", 
                            RowBox[{"m", " ", 
                              SubscriptBox["x", "g"]}]}], ")"}], "2"], 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              SuperscriptBox["T", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                            
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]}], 
                          ")"}]}]]}]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "P"}], ")"}], "2"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{
                          FractionBox[
                            SubscriptBox["p", "g"], 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                          FractionBox[
                            RowBox[{"T", " ", 
                              RowBox[{"(", 
                                RowBox[{"c", "+", "L", "-", 
                                  SubscriptBox["x", "g"]}], ")"}]}], 
                            RowBox[{"m", " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                        RowBox[{
                          SubscriptBox["\[Sigma]", "p"], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{
                                FractionBox["1", 
                                  SubsuperscriptBox["\[Sigma]", "p", "2"]], 
                                "+", 
                                FractionBox[
                                  SuperscriptBox["T", "2"], 
                                  RowBox[{
                                    SuperscriptBox["m", "2"], " ", 
                                    
                                    SubsuperscriptBox["\[Sigma]", "x", 
                                      "2"]}]]}], ")"}], 
                            RowBox[{"3", "/", "2"}]]}]]}], "+", 
                    FractionBox[
                      RowBox[{
                        SubscriptBox["p", "g"], "+", 
                        FractionBox[
                          RowBox[{"T", " ", 
                            RowBox[{"(", 
                              RowBox[{"c", "+", "L", "-", 
                                SubscriptBox["x", "g"]}], ")"}], " ", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
                          RowBox[{"m", " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"1", "+", 
                            FractionBox[
                              RowBox[{
                                SuperscriptBox["T", "2"], " ", 
                                SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
                              RowBox[{
                                SuperscriptBox["m", "2"], " ", 
                                SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                          ")"}], 
                        RowBox[{"3", "/", "2"}]]]}], ")"}]}], 
              RowBox[{"4", " ", "m", " ", 
                SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]], " ", 
                SubscriptBox["\[Sigma]", "x"]}]], ",", 
            FractionBox[
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    FractionBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"-", "c"}], " ", "m"}], "+", 
                            RowBox[{"L", " ", "m"}], "+", 
                            RowBox[{
                              SubscriptBox["p", "g"], " ", "T"}], "+", 
                            RowBox[{"m", " ", 
                              SubscriptBox["x", "g"]}]}], ")"}], "2"], 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              SuperscriptBox["T", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                            
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]}], 
                          ")"}]}]]}]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"1", "+", "P"}], ")"}], "2"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[Sigma]", "p"], " ", 
                      SqrtBox[
                        RowBox[{
                          FractionBox["1", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                          FractionBox[
                            SuperscriptBox["T", "2"], 
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]]}],
                     "-", 
                    SqrtBox[
                      RowBox[{"1", "+", 
                        FractionBox[
                          RowBox[{
                            SuperscriptBox["T", "2"], " ", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
                          RowBox[{
                            SuperscriptBox["m", "2"], " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]]}], 
                  ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"c", " ", "T", " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "-", 
                    RowBox[{"L", " ", "T", " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "-", 
                    RowBox[{"T", " ", 
                      SubscriptBox["x", "g"], " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                    RowBox[{"m", " ", 
                      SubscriptBox["p", "g"], " ", 
                      SubsuperscriptBox["\[Sigma]", "x", "2"]}]}], ")"}]}], 
              RowBox[{"4", " ", 
                SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]], " ", 
                SqrtBox[
                  RowBox[{
                    FractionBox["1", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                    FractionBox[
                      SuperscriptBox["T", "2"], 
                      RowBox[{
                        SuperscriptBox["m", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], " ", 
                SqrtBox[
                  RowBox[{"1", "+", 
                    FractionBox[
                      RowBox[{
                        SuperscriptBox["T", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
                      RowBox[{
                        SuperscriptBox["m", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["T", "2"], " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "3"], " ", 
                      SubscriptBox["\[Sigma]", "x"]}], "+", 
                    RowBox[{
                      SuperscriptBox["m", "2"], " ", 
                      SubscriptBox["\[Sigma]", "p"], " ", 
                      SubsuperscriptBox["\[Sigma]", "x", "3"]}]}], ")"}]}]], 
            ",", 
            FractionBox[
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    FractionBox[
                      RowBox[{
                        RowBox[{
                          SuperscriptBox["c", "2"], " ", 
                          SuperscriptBox["m", "2"]}], "+", 
                        RowBox[{
                          SuperscriptBox["L", "2"], " ", 
                          SuperscriptBox["m", "2"]}], "-", 
                        RowBox[{"2", " ", "c", " ", "m", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                SubscriptBox["p", "g"], " ", "T"}], "+", 
                              RowBox[{"m", " ", 
                                SubscriptBox["x", "g"]}]}], ")"}]}], "+", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                SubscriptBox["p", "g"], " ", "T"}], "+", 
                              RowBox[{"m", " ", 
                                SubscriptBox["x", "g"]}]}], ")"}], "2"]}], 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              SuperscriptBox["T", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                            
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]}], 
                          ")"}]}]]}]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["P", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", 
                        SubscriptBox["\[Sigma]", "p"]}], " ", 
                      SqrtBox[
                        RowBox[{
                          FractionBox["1", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                          FractionBox[
                            SuperscriptBox["T", "2"], 
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]]}],
                     "+", 
                    SqrtBox[
                      RowBox[{"1", "+", 
                        FractionBox[
                          RowBox[{
                            SuperscriptBox["T", "2"], " ", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
                          RowBox[{
                            SuperscriptBox["m", "2"], " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]]}], 
                  ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"c", " ", "T", " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "-", 
                    RowBox[{"T", " ", 
                      SubscriptBox["x", "g"], " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                    RowBox[{"m", " ", 
                      SubscriptBox["p", "g"], " ", 
                      SubsuperscriptBox["\[Sigma]", "x", "2"]}]}], ")"}], " ",
                 
                RowBox[{"Cos", "[", 
                  FractionBox[
                    RowBox[{"L", " ", "m", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"c", " ", "T", " ", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]}], "-", 
                          RowBox[{"T", " ", 
                            SubscriptBox["x", "g"], " ", 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]}], "+", 
                          RowBox[{"m", " ", 
                            SubscriptBox["p", "g"], " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]}], 
                        ")"}]}], 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["T", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "p", "3"], " ", 
                        SubscriptBox["\[Sigma]", "x"]}], "+", 
                      RowBox[{
                        SuperscriptBox["m", "2"], " ", 
                        SubscriptBox["\[Sigma]", "p"], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "3"]}]}]], "]"}]}],
               
              RowBox[{"2", " ", 
                SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]], " ", 
                SqrtBox[
                  RowBox[{
                    FractionBox["1", 
                      SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                    FractionBox[
                      SuperscriptBox["T", "2"], 
                      RowBox[{
                        SuperscriptBox["m", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], " ", 
                SqrtBox[
                  RowBox[{"1", "+", 
                    FractionBox[
                      RowBox[{
                        SuperscriptBox["T", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
                      RowBox[{
                        SuperscriptBox["m", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["T", "2"], " ", 
                      SubsuperscriptBox["\[Sigma]", "p", "3"], " ", 
                      SubscriptBox["\[Sigma]", "x"]}], "+", 
                    RowBox[{
                      SuperscriptBox["m", "2"], " ", 
                      SubscriptBox["\[Sigma]", "p"], " ", 
                      SubsuperscriptBox["\[Sigma]", "x", "3"]}]}], ")"}]}]]}],
           "}"}]}], "}"}]], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["\<\
Pieces for the count rate of the time interference component \
expressed in the new variables\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"comexp", "=", 
        RowBox[{"Exp", "[", 
          RowBox[{"-", 
            FractionBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox["t", "3"], "-", 
                    SubscriptBox["t", "i"]}], ")"}], "2"], 
              RowBox[{"2", " ", 
                SuperscriptBox[
                  SubscriptBox["t", "\[Sigma]"], "2"], " ", 
                SuperscriptBox[
                  SubscriptBox["\[Zeta]", "\[Tau]2"], "2"], " ", 
                SuperscriptBox[
                  SubscriptBox["\[Zeta]\[Prime]", "3"], "2"]}]]}], "]"}]}], 
      ";", 
      RowBox[{"expplusl", "=", 
        RowBox[{"Exp", "[", 
          RowBox[{"-", 
            FractionBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"u", " ", 
                        SubscriptBox["p", "ct"]}], 
                      SubscriptBox["\[Sigma]", "p"]], "+", 
                    SubscriptBox["v", "+"]}], ")"}], "2"], 
              RowBox[{"2", " ", 
                RowBox[{
                  SuperscriptBox["u\[Prime]", "2"], "/", 
                  SuperscriptBox[
                    SubscriptBox["\[Zeta]\[Prime]", "3"], "2"]}]}]]}], 
          "]"}]}], ";", 
      RowBox[{"expminusl", "=", 
        RowBox[{"Exp", "[", 
          RowBox[{"-", 
            FractionBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"u", " ", 
                        SubscriptBox["p", "ct"]}], 
                      SubscriptBox["\[Sigma]", "p"]], "+", 
                    SubscriptBox["v", "-"]}], ")"}], "2"], 
              RowBox[{"2", " ", 
                RowBox[{
                  SuperscriptBox["u\[Prime]", "2"], "/", 
                  SuperscriptBox[
                    SubscriptBox["\[Zeta]\[Prime]", "3"], "2"]}]}]]}], 
          "]"}]}], ";", 
      RowBox[{"prefac", "=", 
        RowBox[{
          FractionBox["k", 
            RowBox[{
              SqrtBox[
                RowBox[{"2", " ", "\[Pi]"}]], "m", " ", "h"}]], 
          FractionBox[
            RowBox[{
              SubscriptBox["p", "ct"], " ", 
              SubscriptBox["\[Sigma]", "p"]}], 
            SqrtBox[
              RowBox[{
                SubscriptBox["\[Zeta]", "\[Tau]2"], "u\[Prime]"}]]]}]}], ";", 
      
      RowBox[{"cosplusl", "=", 
        RowBox[{"Cos", "[", 
          RowBox[{
            RowBox[{
              FractionBox["1", 
                SuperscriptBox["u\[Prime]", "2"]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      SubscriptBox["\[Zeta]\[Prime]", "3"], "4"], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"u", 
                          FractionBox[
                            SuperscriptBox[
                              SubscriptBox["p", "ct"], "2"], 
                            RowBox[{"2", " ", 
                              SuperscriptBox[
                                SubscriptBox["\[Sigma]", "p"], "2"]}]]}], "+",
                         
                        RowBox[{
                          SubscriptBox["v", "+"], 
                          FractionBox[
                            SubscriptBox["p", "ct"], 
                            SubscriptBox["\[Sigma]", "p"]]}]}], ")"}]}], "-", 
                  
                  RowBox[{"u", " ", 
                    FractionBox[
                      SuperscriptBox[
                        SubscriptBox["v", "+"], "2"], "2"]}]}], ")"}]}], "+", 
            
            SubscriptBox["\[Gamma]", "1"], "+", 
            SubscriptBox["\[Gamma]", "2"], "-", 
            FractionBox["\[Pi]", "4"]}], "]"}]}], ";", 
      RowBox[{"cosminusl", "=", 
        RowBox[{"Cos", "[", 
          RowBox[{
            RowBox[{
              FractionBox["1", 
                SuperscriptBox["u\[Prime]", "2"]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      SubscriptBox["\[Zeta]\[Prime]", "3"], "4"], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"u", 
                          FractionBox[
                            SuperscriptBox[
                              SubscriptBox["p", "ct"], "2"], 
                            RowBox[{"2", " ", 
                              SuperscriptBox[
                                SubscriptBox["\[Sigma]", "p"], "2"]}]]}], "+",
                         
                        RowBox[{
                          SubscriptBox["v", "-"], 
                          FractionBox[
                            SubscriptBox["p", "ct"], 
                            SubscriptBox["\[Sigma]", "p"]]}]}], ")"}]}], "-", 
                  
                  RowBox[{"u", " ", 
                    FractionBox[
                      SuperscriptBox[
                        SubscriptBox["v", "-"], "2"], "2"]}]}], ")"}]}], "+", 
            
            SubscriptBox["\[Gamma]", "1"], "+", 
            SubscriptBox["\[Gamma]", "2"], "-", 
            FractionBox["\[Pi]", "4"]}], "]"}]}], ";"}]], "Input",
  CellLabel->"In[36]:="],

Cell["For the antihermitianterms", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"prefac2", "=", 
        RowBox[{"I", " ", "prefac"}]}], ";", " ", 
      RowBox[{"cosplusl2", "=", 
        RowBox[{"cosplusl", "/.", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"\[Pi]", "/", "4"}], "->", 
              RowBox[{
                RowBox[{"-", "\[Pi]"}], "/", "4"}]}], "}"}]}]}], ";", 
      RowBox[{"cosminusl2", "=", 
        RowBox[{"cosminusl", "/.", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"\[Pi]", "/", "4"}], "->", 
              RowBox[{
                RowBox[{"-", "\[Pi]"}], "/", "4"}]}], "}"}]}]}], 
      ";"}]], "Input",
  CellLabel->"In[37]:="],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Map", "[", 
      RowBox[{"Simplify", ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SubscriptBox["p", "ct"], "-", 
              SubscriptBox["p", "4"]}], ",", 
            RowBox[{
              RowBox[{"u", "/", 
                RowBox[{"(", 
                  RowBox[{"2", " ", 
                    SuperscriptBox[
                      SubscriptBox["\[Sigma]", "p"], "2"]}], ")"}]}], "-", 
              SubscriptBox["c", "2"]}], ",", 
            RowBox[{
              RowBox[{
                SubscriptBox["\[Sigma]", "p"], 
                SubscriptBox["c", 
                  RowBox[{"1", "+"}]]}], "-", 
              SubscriptBox["v", "+"]}], ",", 
            RowBox[{
              RowBox[{
                SubscriptBox["\[Sigma]", "p"], 
                SubscriptBox["c", 
                  RowBox[{"1", "-"}]]}], "-", 
              SubscriptBox["v", "-"]}], ",", 
            RowBox[{"Y", "-", 
              FractionBox[
                SuperscriptBox[
                  SubscriptBox["\[Zeta]\[Prime]", "3"], "2"], 
                RowBox[{"2", " ", 
                  SuperscriptBox[
                    SubscriptBox["\[Sigma]", "p"], "2"]}]]}], ",", 
            RowBox[{
              SubscriptBox["R", "t"], "/", 
              FractionBox["u\[Prime]", 
                RowBox[{"2", " ", 
                  SuperscriptBox[
                    SubscriptBox["\[Sigma]", "p"], "2"]}]]}], ",", 
            RowBox[{"\[Gamma]", "-", 
              RowBox[{"ArcTan", "[", 
                FractionBox["u", 
                  SuperscriptBox[
                    SubscriptBox["\[Zeta]\[Prime]", "3"], "2"]], "]"}]}], ",",
             
            RowBox[{
              SubscriptBox["c", "0"], "-", 
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox["\[Gamma]", "1"], "+", 
                  RowBox[{
                    FractionBox["1", "2"], 
                    RowBox[{"ArcTan", "[", 
                      FractionBox[
                        SubscriptBox["t", "\[Zeta]"], 
                        RowBox[{"\[Tau]", "/", "2"}]], "]"}]}], "-", 
                  FractionBox["\[Pi]", "4"]}], ")"}]}], ",", 
            RowBox[{
              SubscriptBox["c", "0"], "+", 
              FractionBox["\[Gamma]", "2"], "-", 
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox["\[Gamma]", "1"], "+", 
                  SubscriptBox["\[Gamma]", "2"], "-", 
                  RowBox[{"\[Pi]", "/", "4"}]}], ")"}]}], ",", 
            RowBox[{"oldcomexp", "-", "comexp"}], ",", 
            RowBox[{"oldexpplusl", "-", "expplusl"}], ",", 
            RowBox[{"oldexpminusl", "-", "expminusl"}], ",", 
            RowBox[{"oldprefac", "-", "prefac"}], ",", 
            RowBox[{"oldcosplusl", "-", "cosplusl"}], ",", 
            RowBox[{"oldcosminusl", "-", "cosminusl"}]}], "}"}]}], 
      "]"}]], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "0", ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "0", ",", "1", ",", 
        "0", ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell["\<\
The count rate of the interference term is finally also \
equal:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Simplify", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"prefac", " ", "comexp", " ", "expplusl"}], " ", "-", " ",
             
            RowBox[{"oldprefac", " ", "oldcomexp", " ", "oldexpplusl"}]}], 
          ",", 
          RowBox[{
            RowBox[{"prefac", " ", "comexp", " ", "expminusl"}], " ", "-", 
            " ", 
            RowBox[{"oldprefac", " ", "oldcomexp", " ", "oldexpminusl"}]}]}], 
        "}"}], "]"}]], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{"CIplus", "=", 
        RowBox[{"prefac", " ", "comexp", " ", "expplusl", " ", "cosplusl"}]}],
       ";", 
      RowBox[{"CIminus", "=", 
        RowBox[{
        "prefac", " ", "comexp", " ", "expminusl", " ", "cosminusl"}]}], ";", 
      " ", 
      RowBox[{"CI2plus", "=", 
        RowBox[{
        "prefac2", " ", "comexp", " ", "expplusl", " ", "cosplusl2"}]}], ";", 
      " ", 
      RowBox[{"CI2minus", "=", 
        RowBox[{"CIminus", "=", 
          RowBox[{
          "prefac2", " ", "comexp", " ", "expminusl", " ", "cosminusl2"}]}]}],
       ";", " ", 
      RowBox[{"CI", "=", 
        RowBox[{"CIplus", "+", "CIminus"}]}], ";", 
      RowBox[{"CI2", "=", 
        RowBox[{"CIplus2", "+", "CIminus2"}]}], ";"}]], "Input",
  CellLabel->"In[38]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total one-particle count", "Subtitle"],

Cell["\<\
Note that this formula assumes the overlap between the two original \
time components to be 0. See Table 5.2 and Eq. (5.22), (5.28).\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"CT", "=", 
        RowBox[{
          FractionBox["1", "2"], 
          RowBox[{"(", 
            RowBox[{"CL", "+", "CE", "+", 
              RowBox[{"2", " ", 
                RowBox[{"Re", "[", "\[Eta]", "]"}], " ", "CI"}], " ", "+", 
              RowBox[{"2", " ", "I", " ", 
                RowBox[{"Im", "[", "\[Eta]", "]"}], " ", "CI2"}]}], ")"}]}]}],
       ";"}]], "Input",
  CellLabel->"In[24]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two-particle count rates", "Subtitle"],

Cell["\<\
The non-subindexed quantities correspond to interferometer A.\
\>", \
"Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            SubscriptBox["CE", "B"], ",", 
            SubscriptBox["CL", "B"], ",", 
            SubscriptBox["prefac", "B"], ",", 
            SubscriptBox["comexp", "B"], ",", 
            SubscriptBox["expplusl", "B"], ",", 
            SubscriptBox["expminusl", "B"], ",", 
            SubscriptBox["cosplusl", "B"], ",", 
            SubscriptBox["cosminusl", "B"], ",", 
            SubscriptBox["cosplusl2", "B"], ",", 
            SubscriptBox["cosminusl2", "B"]}], "}"}], "=", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
            "CE", ",", "CL", ",", "prefac", ",", "comexp", ",", "expplusl", 
              ",", "expminusl", ",", "cosplusl", ",", "cosminusl", ",", 
              "cosplusl2", ",", "cosminusl2"}], "}"}], "/.", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"L", "->", 
                SubscriptBox["L", "B"]}], ",", 
              RowBox[{"T", "->", 
                SubscriptBox["T", "B"]}], ",", 
              RowBox[{"P", "->", 
                SubscriptBox["P", "B"]}]}], "}"}]}]}], ";"}]], "Input",
  CellLabel->"In[25]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Application to visibilities", "Title"],

Cell["One-particle", "Subtitle"],

Cell[BoxData[
    RowBox[{
      RowBox[{"CIe", "=", 
        RowBox[{"prefac", " ", "comexp", " ", "expplusl"}]}], " ", 
      ";"}]], "Input",
  CellLabel->"In[109]:="],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"vis1p", "=", 
      RowBox[{"2", " ", 
        RowBox[{"Re", "[", "\[Eta]", "]"}], " ", 
        RowBox[{
          RowBox[{"CIe", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "/", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"CL", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "+", 
              RowBox[{"CE", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}]}]], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    FractionBox[
      RowBox[{
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{
            RowBox[{"-", 
              FractionBox[
                RowBox[{
                  SubsuperscriptBox["p", "g", "2"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"T", "-", 
                        FractionBox[
                          RowBox[{"m", " ", 
                            RowBox[{"(", 
                              RowBox[{"c", "-", 
                                SubscriptBox["x", "g"]}], ")"}]}], 
                          SubscriptBox["p", "g"]], "+", 
                        FractionBox["\[Tau]", "2"]}], ")"}], "2"]}], 
                RowBox[{"2", " ", 
                  SuperscriptBox["m", "2"], " ", 
                  SubsuperscriptBox["\[Sigma]", "x", "2"], " ", 
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      FractionBox[
                        RowBox[{
                          SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                          SuperscriptBox["\[Tau]", "2"]}], 
                        RowBox[{"4", " ", 
                          SuperscriptBox["m", "2"], " ", 
                          SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], ")"}],
                   " ", 
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      FractionBox[
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"T", "+", 
                              FractionBox["\[Tau]", "2"]}], ")"}], "2"], 
                        RowBox[{
                          FractionBox[
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}], 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                          FractionBox[
                            SuperscriptBox["\[Tau]", "2"], "4"]}]]}], 
                    ")"}]}]]}], "-", 
            FractionBox[
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    FractionBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"T", "+", 
                            FractionBox["\[Tau]", "2"]}], ")"}], "2"], 
                      RowBox[{
                        FractionBox[
                          RowBox[{
                            SuperscriptBox["m", "2"], " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}], 
                          SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                        FractionBox[
                          SuperscriptBox["\[Tau]", "2"], "4"]}]]}], ")"}], 
                " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      FractionBox["L", 
                        SubscriptBox["\[Sigma]", "x"]], "-", 
                      FractionBox[
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{"c", "-", 
                              SubscriptBox["x", "g"]}], ")"}], " ", 
                          SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                          RowBox[{"(", 
                            RowBox[{"T", "+", 
                              FractionBox["\[Tau]", "2"]}], ")"}], " ", 
                          "\[Tau]"}], 
                        RowBox[{"2", " ", 
                          SuperscriptBox["m", "2"], " ", 
                          SubsuperscriptBox["\[Sigma]", "x", "3"], " ", 
                          RowBox[{"(", 
                            RowBox[{"1", "+", 
                              FractionBox[
                                RowBox[{
                                  SubsuperscriptBox["\[Sigma]", "p", "2"], 
                                  " ", 
                                  SuperscriptBox["\[Tau]", "2"]}], 
                                RowBox[{"4", " ", 
                                  SuperscriptBox["m", "2"], " ", 
                                  
                                  SubsuperscriptBox["\[Sigma]", "x", 
                                    "2"]}]]}], ")"}]}]], "+", 
                      FractionBox[
                        RowBox[{"\[Tau]", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              SubscriptBox["p", "g"], "+", 
                              FractionBox[
                                RowBox[{"m", " ", 
                                  RowBox[{"(", 
                                    RowBox[{"c", "-", 
                                      SubscriptBox["x", "g"]}], ")"}], " ", 
                                  RowBox[{"(", 
                                    RowBox[{"T", "+", 
                                      FractionBox["\[Tau]", "2"]}], ")"}]}], 
                                RowBox[{
                                  FractionBox[
                                    RowBox[{
                                      SuperscriptBox["m", "2"], " ", 
                                      
                                      SubsuperscriptBox["\[Sigma]", "x", 
                                        "2"]}], 
                                    SubsuperscriptBox["\[Sigma]", "p", "2"]], 
                                  "+", 
                                  FractionBox[
                                    SuperscriptBox["\[Tau]", "2"], "4"]}]]}], 
                            ")"}], " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"-", "1"}], "+", 
                              FractionBox[
                                SuperscriptBox[
                                  RowBox[{"(", 
                                    RowBox[{"T", "+", 
                                      FractionBox["\[Tau]", "2"]}], ")"}], 
                                  "2"], 
                                RowBox[{
                                  FractionBox[
                                    RowBox[{
                                      SuperscriptBox["m", "2"], " ", 
                                      
                                      SubsuperscriptBox["\[Sigma]", "x", 
                                        "2"]}], 
                                    SubsuperscriptBox["\[Sigma]", "p", "2"]], 
                                  "+", 
                                  FractionBox[
                                    SuperscriptBox["\[Tau]", "2"], "4"]}]]}], 
                            ")"}]}], 
                        RowBox[{"2", " ", "m", " ", 
                          SubscriptBox["\[Sigma]", "x"], " ", 
                          RowBox[{"(", 
                            RowBox[{"1", "+", 
                              FractionBox[
                                SuperscriptBox[
                                  RowBox[{"(", 
                                    RowBox[{"T", "+", 
                                      FractionBox["\[Tau]", "2"]}], ")"}], 
                                  "2"], 
                                RowBox[{
                                  FractionBox[
                                    RowBox[{
                                      SuperscriptBox["m", "2"], " ", 
                                      
                                      SubsuperscriptBox["\[Sigma]", "x", 
                                        "2"]}], 
                                    SubsuperscriptBox["\[Sigma]", "p", "2"]], 
                                  "+", 
                                  FractionBox[
                                    SuperscriptBox["\[Tau]", "2"], "4"]}]]}], 
                            ")"}]}]]}], ")"}], "2"]}], 
              RowBox[{"2", " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                        SuperscriptBox["\[Tau]", "2"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"-", "1"}], "+", 
                              FractionBox[
                                SuperscriptBox[
                                  RowBox[{"(", 
                                    RowBox[{"T", "+", 
                                      FractionBox["\[Tau]", "2"]}], ")"}], 
                                  "2"], 
                                RowBox[{
                                  FractionBox[
                                    RowBox[{
                                      SuperscriptBox["m", "2"], " ", 
                                      
                                      SubsuperscriptBox["\[Sigma]", "x", 
                                        "2"]}], 
                                    SubsuperscriptBox["\[Sigma]", "p", "2"]], 
                                  "+", 
                                  FractionBox[
                                    SuperscriptBox["\[Tau]", "2"], "4"]}]]}], 
                            ")"}], "2"]}], 
                      RowBox[{"4", " ", 
                        SuperscriptBox["m", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]], "+", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"1", "+", 
                          FractionBox[
                            SuperscriptBox[
                              RowBox[{"(", 
                                RowBox[{"T", "+", 
                                  FractionBox["\[Tau]", "2"]}], ")"}], "2"], 
                            RowBox[{
                              FractionBox[
                                RowBox[{
                                  SuperscriptBox["m", "2"], " ", 
                                  SubsuperscriptBox["\[Sigma]", "x", "2"]}], 
                                SubsuperscriptBox["\[Sigma]", "p", "2"]], "+",
                               
                              FractionBox[
                                SuperscriptBox["\[Tau]", "2"], "4"]}]]}], 
                        ")"}], "2"]}], ")"}]}]]}]], " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            SuperscriptBox["P", "2"]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            SubscriptBox["p", "g"], "+", 
            FractionBox[
              RowBox[{"m", " ", 
                RowBox[{"(", 
                  RowBox[{"c", "-", 
                    SubscriptBox["x", "g"]}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{"T", "+", 
                    FractionBox["\[Tau]", "2"]}], ")"}]}], 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SuperscriptBox["m", "2"], " ", 
                    SubsuperscriptBox["\[Sigma]", "x", "2"]}], 
                  SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                FractionBox[
                  SuperscriptBox["\[Tau]", "2"], "4"]}]]}], ")"}], " ", 
        RowBox[{"Re", "[", "\[Eta]", "]"}]}], 
      RowBox[{"2", " ", "m", " ", 
        SqrtBox[
          RowBox[{"2", " ", "\[Pi]"}]], " ", 
        SubscriptBox["\[Sigma]", "x"], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            FractionBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"T", "+", 
                    FractionBox["\[Tau]", "2"]}], ")"}], "2"], 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SuperscriptBox["m", "2"], " ", 
                    SubsuperscriptBox["\[Sigma]", "x", "2"]}], 
                  SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                FractionBox[
                  SuperscriptBox["\[Tau]", "2"], "4"]}]]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    FractionBox[
                      RowBox[{
                        SubsuperscriptBox["p", "g", "2"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"T", "-", 
                              FractionBox[
                                RowBox[{"m", " ", 
                                  RowBox[{"(", 
                                    RowBox[{"c", "-", "L", "-", 
                                      SubscriptBox["x", "g"]}], ")"}]}], 
                                SubscriptBox["p", "g"]]}], ")"}], "2"]}], 
                      RowBox[{"2", " ", 
                        SuperscriptBox["m", "2"], " ", 
                        RowBox[{"(", 
                          RowBox[{"1", "+", 
                            FractionBox[
                              RowBox[{
                                SuperscriptBox["T", "2"], " ", 
                                SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
                              RowBox[{
                                SuperscriptBox["m", "2"], " ", 
                                SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                          ")"}], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"1", "+", "P"}], ")"}], "2"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox["p", "g"], "+", 
                    FractionBox[
                      RowBox[{"T", " ", 
                        RowBox[{"(", 
                          RowBox[{"c", "-", "L", "-", 
                            SubscriptBox["x", "g"]}], ")"}], " ", 
                        SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
                      RowBox[{"m", " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], ")"}]}],
               
              RowBox[{"4", " ", "m", " ", 
                SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      FractionBox[
                        RowBox[{
                          SuperscriptBox["T", "2"], " ", 
                          SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
                        RowBox[{
                          SuperscriptBox["m", "2"], " ", 
                          SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], ")"}],
                   
                  RowBox[{"3", "/", "2"}]], " ", 
                SubscriptBox["\[Sigma]", "x"]}]], "+", 
            FractionBox[
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                    FractionBox[
                      RowBox[{
                        SubsuperscriptBox["p", "g", "2"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"T", "-", 
                              FractionBox[
                                RowBox[{"m", " ", 
                                  RowBox[{"(", 
                                    RowBox[{"c", "+", "L", "-", 
                                      SubscriptBox["x", "g"]}], ")"}]}], 
                                SubscriptBox["p", "g"]], "+", "\[Tau]"}], 
                            ")"}], "2"]}], 
                      RowBox[{"2", " ", 
                        SuperscriptBox["m", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"], " ", 
                        RowBox[{"(", 
                          RowBox[{"1", "+", 
                            FractionBox[
                              RowBox[{
                                SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                                
                                SuperscriptBox[
                                  RowBox[{"(", 
                                    RowBox[{"T", "+", "\[Tau]"}], ")"}], 
                                  "2"]}], 
                              RowBox[{
                                SuperscriptBox["m", "2"], " ", 
                                SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                          ")"}]}]]}]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"1", "-", "P"}], ")"}], "2"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox["p", "g"], "+", 
                    FractionBox[
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{"c", "+", "L", "-", 
                            SubscriptBox["x", "g"]}], ")"}], " ", 
                        SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                        RowBox[{"(", 
                          RowBox[{"T", "+", "\[Tau]"}], ")"}]}], 
                      RowBox[{"m", " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], ")"}]}],
               
              RowBox[{"4", " ", "m", " ", 
                SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]], " ", 
                SubscriptBox["\[Sigma]", "x"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      FractionBox[
                        RowBox[{
                          SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"T", "+", "\[Tau]"}], ")"}], "2"]}], 
                        RowBox[{
                          SuperscriptBox["m", "2"], " ", 
                          SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], ")"}],
                   
                  RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
        SqrtBox[
          RowBox[{
            SqrtBox[
              RowBox[{"1", "+", 
                FractionBox[
                  RowBox[{
                    SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                    SuperscriptBox["\[Tau]", "2"]}], 
                  RowBox[{"4", " ", 
                    SuperscriptBox["m", "2"], " ", 
                    SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], " ", 
            SqrtBox[
              RowBox[{
                FractionBox[
                  RowBox[{
                    SubsuperscriptBox["\[Sigma]", "p", "2"], " ", 
                    SuperscriptBox["\[Tau]", "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"-", "1"}], "+", 
                          FractionBox[
                            SuperscriptBox[
                              RowBox[{"(", 
                                RowBox[{"T", "+", 
                                  FractionBox["\[Tau]", "2"]}], ")"}], "2"], 
                            RowBox[{
                              FractionBox[
                                RowBox[{
                                  SuperscriptBox["m", "2"], " ", 
                                  SubsuperscriptBox["\[Sigma]", "x", "2"]}], 
                                SubsuperscriptBox["\[Sigma]", "p", "2"]], "+",
                               
                              FractionBox[
                                SuperscriptBox["\[Tau]", "2"], "4"]}]]}], 
                        ")"}], "2"]}], 
                  RowBox[{"4", " ", 
                    SuperscriptBox["m", "2"], " ", 
                    SubsuperscriptBox["\[Sigma]", "x", "2"]}]], "+", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      FractionBox[
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"T", "+", 
                              FractionBox["\[Tau]", "2"]}], ")"}], "2"], 
                        RowBox[{
                          FractionBox[
                            RowBox[{
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}], 
                            SubsuperscriptBox["\[Sigma]", "p", "2"]], "+", 
                          FractionBox[
                            SuperscriptBox["\[Tau]", "2"], "4"]}]]}], ")"}], 
                  "2"]}]]}]]}]]], "Output",
  CellLabel->"Out[110]="]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{"countpt", "=", 
        RowBox[{
          RowBox[{"2", " ", 
            RowBox[{"Re", "[", "\[Eta]", "]"}], " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                "prefac", " ", "comexp", " ", "expplusl", " ", "cosplusl"}], 
                ")"}], "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"CL", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "+", 
              RowBox[{"CE", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}], ";"}]], "Input",
  CellLabel->"In[111]:="],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"simp\[Sigma]v1p", "=", " ", 
      RowBox[{"Simplify", " ", "@", " ", 
        RowBox[{"Series", "[", 
          RowBox[{"vis1p", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["\[Sigma]", "p"], ",", "0", ",", "1"}], "}"}]}], 
          "]"}]}]}]], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            RowBox[{"2", " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                    FractionBox[
                      RowBox[{
                        RowBox[{"2", " ", 
                          SuperscriptBox["c", "2"], " ", 
                          SuperscriptBox["m", "2"]}], "+", 
                        RowBox[{"2", " ", 
                          SuperscriptBox["L", "2"], " ", 
                          SuperscriptBox["m", "2"]}], "+", 
                        RowBox[{"2", " ", 
                          SubsuperscriptBox["p", "g", "2"], " ", 
                          SuperscriptBox["T", "2"]}], "+", 
                        RowBox[{"4", " ", "m", " ", 
                          SubscriptBox["p", "g"], " ", "T", " ", 
                          SubscriptBox["x", "g"]}], "+", 
                        RowBox[{"2", " ", 
                          SuperscriptBox["m", "2"], " ", 
                          SubsuperscriptBox["x", "g", "2"]}], "-", 
                        RowBox[{"2", " ", "L", " ", "m", " ", 
                          SubscriptBox["p", "g"], " ", "\[Tau]"}], "+", 
                        RowBox[{"2", " ", 
                          SubsuperscriptBox["p", "g", "2"], " ", "T", " ", 
                          "\[Tau]"}], "+", 
                        RowBox[{"2", " ", "m", " ", 
                          SubscriptBox["p", "g"], " ", 
                          SubscriptBox["x", "g"], " ", "\[Tau]"}], "+", 
                        RowBox[{
                          SubsuperscriptBox["p", "g", "2"], " ", 
                          SuperscriptBox["\[Tau]", "2"]}], "-", 
                        RowBox[{"2", " ", "c", " ", "m", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"2", " ", "m", " ", 
                                SubscriptBox["x", "g"]}], "+", 
                              RowBox[{
                                SubscriptBox["p", "g"], " ", 
                                RowBox[{"(", 
                                  RowBox[{
                                    RowBox[{"2", " ", "T"}], "+", "\[Tau]"}], 
                                  ")"}]}]}], ")"}]}]}], 
                      RowBox[{"4", " ", 
                        SuperscriptBox["m", "2"], " ", 
                        SubsuperscriptBox["\[Sigma]", "x", "2"]}]]], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", 
                      SuperscriptBox["P", "2"]}], ")"}], " ", 
                  RowBox[{"Re", "[", "\[Eta]", "]"}]}], ")"}]}], 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  FractionBox[
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"-", "c"}], " ", "m"}], "+", 
                          RowBox[{"L", " ", "m"}], "+", 
                          RowBox[{
                            SubscriptBox["p", "g"], " ", "T"}], "+", 
                          RowBox[{"m", " ", 
                            SubscriptBox["x", "g"]}]}], ")"}], "2"], 
                    RowBox[{"2", " ", 
                      SuperscriptBox["m", "2"], " ", 
                      SubsuperscriptBox["\[Sigma]", "x", "2"]}]]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "P"}], ")"}], "2"]}], "+", 
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  FractionBox[
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"-", "c"}], " ", "m"}], "-", 
                          RowBox[{"L", " ", "m"}], "+", 
                          RowBox[{
                            SubscriptBox["p", "g"], " ", "T"}], "+", 
                          RowBox[{"m", " ", 
                            SubscriptBox["x", "g"]}], "+", 
                          RowBox[{
                            SubscriptBox["p", "g"], " ", "\[Tau]"}]}], ")"}], 
                      "2"], 
                    RowBox[{"2", " ", 
                      SuperscriptBox["m", "2"], " ", 
                      SubsuperscriptBox["\[Sigma]", "x", "2"]}]]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"1", "+", "P"}], ")"}], "2"]}]}]]}], "+", 
        InterpretationBox[
          SuperscriptBox[
            RowBox[{"O", "[", 
              SubscriptBox["\[Sigma]", "p"], "]"}], "2"],
          
          SeriesData[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]p, 0, {},
             0, 2, 1],
          Editable->False]}],
      SeriesData[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]p, 0, {
        Times[ -2, 
          Power[ E, 
            Times[ 
              Rational[ 1, 4], 
              Power[ m, -2], 
              Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x, -2], 
              Plus[ 
                Times[ 2, 
                  Power[ c, 2], 
                  Power[ m, 2]], 
                Times[ 2, 
                  Power[ L, 2], 
                  Power[ m, 2]], 
                Times[ 2, 
                  Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                  Power[ T, 2]], 
                Times[ 
                4, m, p\[UnderBracket]Subscript\[UnderBracket]g, T, 
                  x\[UnderBracket]Subscript\[UnderBracket]g], 
                Times[ 2, 
                  Power[ m, 2], 
                  Power[ x\[UnderBracket]Subscript\[UnderBracket]g, 2]], 
                
                Times[ -2, L, m, 
                  p\[UnderBracket]Subscript\[UnderBracket]g, \[Tau]], 
                Times[ 2, 
                  Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                  T, \[Tau]], 
                Times[ 
                2, m, p\[UnderBracket]Subscript\[UnderBracket]g, 
                  x\[UnderBracket]Subscript\[UnderBracket]g, \[Tau]], 
                Times[ 
                  Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                  Power[ \[Tau], 2]], 
                Times[ -2, c, m, 
                  Plus[ 
                    Times[ 2, m, x\[UnderBracket]Subscript\[UnderBracket]g], 
                    Times[ p\[UnderBracket]Subscript\[UnderBracket]g, 
                      Plus[ 
                        Times[ 2, T], \[Tau]]]]]]]], 
          Plus[ -1, 
            Power[ P, 2]], 
          Power[ 
            Plus[ 
              Times[ 
                Power[ E, 
                  Times[ 
                    Rational[ 1, 2], 
                    Power[ m, -2], 
                    Power[ 
                      Plus[ 
                        Times[ -1, c, m], 
                        Times[ L, m], 
                        Times[ p\[UnderBracket]Subscript\[UnderBracket]g, T], 
                        
                        Times[ m, x\[UnderBracket]Subscript\[UnderBracket]g]],
                       2], 
                    
                    Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x, \
-2]]], 
                Power[ 
                  Plus[ -1, P], 2]], 
              Times[ 
                Power[ E, 
                  Times[ 
                    Rational[ 1, 2], 
                    Power[ m, -2], 
                    
                    Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x, \
-2], 
                    Power[ 
                      Plus[ 
                        Times[ -1, c, m], 
                        Times[ -1, L, m], 
                        Times[ p\[UnderBracket]Subscript\[UnderBracket]g, T], 
                        
                        Times[ m, x\[UnderBracket]Subscript\[UnderBracket]g], 
                        
                        Times[ 
                        p\[UnderBracket]Subscript\[UnderBracket]g, \[Tau]]], 
                      2]]], 
                Power[ 
                  Plus[ 1, P], 2]]], -1], 
          Re[ \[Eta]]]}, 0, 2, 1],
      Editable->False]], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"simpv1p", "=", "  ", 
      RowBox[{"Normal", " ", "@", 
        RowBox[{"Simplify", " ", "@", " ", 
          RowBox[{"Series", "[", 
            RowBox[{"simp\[Sigma]v1p", ",", 
              RowBox[{"{", 
                RowBox[{"L", ",", 
                  SubscriptBox["l", "pt"], ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"T", ",", 
                  SubscriptBox["t", "pt"], ",", "1"}], "}"}]}], 
            "]"}]}]}]}]], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["P", "2"]}], ")"}], " ", 
            RowBox[{"Re", "[", "\[Eta]", "]"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox["P", "2"]}]]}], "-", 
      FractionBox[
        RowBox[{"2", " ", "P", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["P", "2"]}], ")"}], " ", 
          SubscriptBox["p", "g"], " ", 
          RowBox[{"(", 
            RowBox[{"T", "-", 
              FractionBox[
                RowBox[{"m", " ", 
                  RowBox[{"(", 
                    RowBox[{"c", "-", 
                      SubscriptBox["x", "g"]}], ")"}]}], 
                SubscriptBox["p", "g"]], "+", 
              FractionBox["\[Tau]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"L", "-", 
              FractionBox[
                RowBox[{
                  SubscriptBox["p", "g"], " ", "\[Tau]"}], 
                RowBox[{"2", " ", "m"}]]}], ")"}], " ", 
          RowBox[{"Re", "[", "\[Eta]", "]"}]}], 
        RowBox[{"m", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox["P", "2"]}], ")"}], "2"], " ", 
          SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{"simpltv1p", "=", " ", 
        RowBox[{"Series", "[", 
          RowBox[{"vis1p", ",", 
            RowBox[{"{", 
              RowBox[{"L", ",", 
                SubscriptBox["l", "pt"], ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"T", ",", 
                SubscriptBox["t", "pt"], ",", "1"}], "}"}]}], "]"}]}], " ", 
      RowBox[{"(*", 
        RowBox[{"far", " ", "too", " ", "messy"}], "*)"}], ";"}]], "Input",
  CellLabel->"In[60]:="],

Cell[CellGroupData[{

Cell["Two particles", "Subtitle"],

Cell["Here it is supposing \[Eta] real.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"vis2p", "=", 
        RowBox[{"2", 
          RowBox[{"Re", "[", "\[Eta]", "]"}], " ", 
          FractionBox[
            RowBox[{
              RowBox[{"prefac", "[", 
                RowBox[{"[", "3", "]"}], "]"}], " ", 
              RowBox[{"comexp", "[", 
                RowBox[{"[", "3", "]"}], "]"}], 
              RowBox[{"expplusl", "[", 
                RowBox[{"[", "3", "]"}], "]"}], " ", 
              RowBox[{
                SubscriptBox["prefac", "B"], "[", 
                RowBox[{"[", "3", "]"}], "]"}], 
              RowBox[{
                SubscriptBox["comexp", "B"], "[", 
                RowBox[{"[", "3", "]"}], "]"}], 
              RowBox[{
                SubscriptBox["expplusl", "B"], "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"CL", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], 
                RowBox[{
                  SubscriptBox["CL", "B"], "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"CE", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], " ", 
                RowBox[{
                  SubscriptBox["CE", "B"], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}]}]]}]}], ";"}]], "Input",
  CellLabel->"In[67]:="],

Cell[TextData[{
  "Warning! When ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["L", "B"], "=", 
            RowBox[{
              SubscriptBox["l", "pt"], " ", "increasing", " ", 
              "predictability", " ", "leads", " ", "to", " ", "decreasing", 
              " ", 
              RowBox[{"visibility", ".", " ", "However"}]}]}], ",", " ", 
          RowBox[{
          "the", " ", "converse", " ", "is", " ", "true", " ", "if", " ", 
            SubscriptBox["L", "B"], " ", "is", " ", "shifted", " ", "away", 
            " ", "from", " ", 
            RowBox[{
              SubscriptBox["l", "pt"], ".", "\[IndentingNewLine]"}]}]}], 
        TraditionalForm]]],
  "\nA very clear (and expected) effect of visibility reduction is found when \
shifting not only ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["L", "B"], " ", "away", " ", "by", " ", 
            SubscriptBox["\[CapitalDelta]L", "B"], " ", "from", " ", 
            SubscriptBox["l", "pt"]}], ",", " ", 
          RowBox[{"but", " ", "also", " ", 
            SubscriptBox["T", "B"], " "}]}], TraditionalForm]]],
  " away from ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["t", "pt"], " ", "by", " ", 
            SubscriptBox["\[CapitalDelta]T", "B"]}], "=", 
          RowBox[{"m", " ", 
            RowBox[{
              SubscriptBox["\[CapitalDelta]L", "B"], "/", 
              SubscriptBox["p", "g"]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Block", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"\[Tau]", "=", "50"}], ",", 
              RowBox[{
                SubscriptBox["\[Sigma]", "p"], "=", 
                RowBox[{"1", "/", "80"}]}], ",", 
              RowBox[{"P", "=", "0.8"}], ",", 
              RowBox[{
                SubscriptBox["x", "g"], "=", 
                RowBox[{"-", "80"}]}], ",", 
              RowBox[{"c", "=", "100"}], ",", 
              RowBox[{
                SubscriptBox["p", "g"], "=", "1"}], ",", 
              RowBox[{
                SubscriptBox["\[Sigma]", "x"], "=", "1"}], ",", 
              RowBox[{"m", "=", "1"}], ",", 
              RowBox[{
                SubscriptBox["P", "B"], "=", "0"}], ",", 
              RowBox[{
                SubscriptBox["L", "B"], "=", 
                RowBox[{
                  SubscriptBox["l", "pt"], "+", "2"}]}], ",", 
              RowBox[{
                SubscriptBox["T", "B"], "=", 
                SubscriptBox["t", "pt"]}], ",", 
              RowBox[{"T", "=", 
                SubscriptBox["t", "pt"]}], ",", 
              RowBox[{"\[Eta]", "=", "1"}]}], "}"}], ",", 
          RowBox[{"Plot", "[", 
            RowBox[{
              RowBox[{"Evaluate", "[", "vis2p", "]"}], ",", 
              RowBox[{"{", 
                RowBox[{"L", ",", 
                  RowBox[{
                    SubscriptBox["l", "pt"], "-", "8"}], ",", 
                  RowBox[{
                    SubscriptBox["l", "pt"], "+", "8"}]}], "}"}], ",", 
              RowBox[{"PlotRange", "->", 
                RowBox[{"{", 
                  RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}], "]"}], 
      "\[IndentingNewLine]"}]], "Input",
  CellLabel->"In[75]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.988095 0.0595238 0 0.618034 [
[.05357 -0.0125 -12 -9 ]
[.05357 -0.0125 12 0 ]
[.35119 -0.0125 -12 -9 ]
[.35119 -0.0125 12 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.64881 -0.0125 -12 -9 ]
[.64881 -0.0125 12 0 ]
[.79762 -0.0125 -6 -9 ]
[.79762 -0.0125 6 0 ]
[.94643 -0.0125 -12 -9 ]
[.94643 -0.0125 12 0 ]
[.18988 .12361 -18 -4.5 ]
[.18988 .12361 0 4.5 ]
[.18988 .24721 -18 -4.5 ]
[.18988 .24721 0 4.5 ]
[.18988 .37082 -18 -4.5 ]
[.18988 .37082 0 4.5 ]
[.18988 .49443 -18 -4.5 ]
[.18988 .49443 0 4.5 ]
[.18988 .61803 -6 -4.5 ]
[.18988 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 0 m
.05357 .00625 L
s
[(17.5)] .05357 -0.0125 0 1 Mshowa
.35119 0 m
.35119 .00625 L
s
[(22.5)] .35119 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(25)] .5 -0.0125 0 1 Mshowa
.64881 0 m
.64881 .00625 L
s
[(27.5)] .64881 -0.0125 0 1 Mshowa
.79762 0 m
.79762 .00625 L
s
[(30)] .79762 -0.0125 0 1 Mshowa
.94643 0 m
.94643 .00625 L
s
[(32.5)] .94643 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.20238 .12361 m
.20863 .12361 L
s
[(0.2)] .18988 .12361 1 0 Mshowa
.20238 .24721 m
.20863 .24721 L
s
[(0.4)] .18988 .24721 1 0 Mshowa
.20238 .37082 m
.20863 .37082 L
s
[(0.6)] .18988 .37082 1 0 Mshowa
.20238 .49443 m
.20863 .49443 L
s
[(0.8)] .18988 .49443 1 0 Mshowa
.20238 .61803 m
.20863 .61803 L
s
[(1)] .18988 .61803 1 0 Mshowa
.125 Mabswid
.20238 .0309 m
.20613 .0309 L
s
.20238 .0618 m
.20613 .0618 L
s
.20238 .09271 m
.20613 .09271 L
s
.20238 .15451 m
.20613 .15451 L
s
.20238 .18541 m
.20613 .18541 L
s
.20238 .21631 m
.20613 .21631 L
s
.20238 .27812 m
.20613 .27812 L
s
.20238 .30902 m
.20613 .30902 L
s
.20238 .33992 m
.20613 .33992 L
s
.20238 .40172 m
.20613 .40172 L
s
.20238 .43262 m
.20613 .43262 L
s
.20238 .46353 m
.20613 .46353 L
s
.20238 .52533 m
.20613 .52533 L
s
.20238 .55623 m
.20613 .55623 L
s
.20238 .58713 m
.20613 .58713 L
s
.25 Mabswid
.20238 0 m
.20238 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36141 m
.06244 .30769 L
.10458 .25989 L
.14415 .22417 L
.18221 .19685 L
.22272 .17396 L
.26171 .15682 L
.30316 .14287 L
.34309 .13286 L
.3815 .12589 L
.40134 .12319 L
.42237 .12096 L
.43178 .12016 L
.4419 .11943 L
.45139 .11887 L
.4602 .11846 L
.47031 .11811 L
.47564 .11798 L
.47838 .11792 L
.48134 .11788 L
.48416 .11784 L
.4854 .11783 L
.48676 .11782 L
.48805 .11781 L
.48925 .11781 L
.49051 .1178 L
.49122 .1178 L
.49187 .1178 L
.49309 .1178 L
.49422 .1178 L
.49546 .11781 L
.49678 .11781 L
.49792 .11782 L
.49899 .11783 L
.50143 .11785 L
.50386 .11789 L
.50612 .11792 L
.51126 .11803 L
.51626 .11817 L
.52161 .11835 L
.5313 .11878 L
.54011 .11927 L
.5593 .12071 L
.58009 .12283 L
.59997 .12544 L
.62101 .12886 L
.6589 .13688 L
.69924 .14842 L
.73806 .16304 L
.77934 .18321 L
Mistroke
.8191 .20821 L
.85735 .23862 L
.89804 .27931 L
.93723 .32797 L
.97619 .38623 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{400, 247.188},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000ma000`40n007h00OomkKTMkK003og]^A
g]/001ONf`@000?Nf`03003NfmkK00?Nf`03003NfmkK00;Nf`<005WNf`@000;Nf`@000?Nf`03003N
fmkK00;Nf`<002SNf`@000;Nf`<002SNf`@000?Nf`03003NfmkK00?Nf`03003NfmkK00;Nf`<002WN
f`8000CNf`8002WNf`8000?Nf`@000?Nf`03003NfmkK00;Nf`<001[Nf`006MkK00<00=kKg]/00]kK
00<00=kKg]/02mkK00<00=kKg]/0E]kK00<00=kKg]/00mkK00<00=kKg]/03=kK00<00=kKg]/09MkK
00<00=kKg]/01]kK00<00=kKg]/09MkK00<00=kKg]/01=kK00<00=kKg]/02mkK00<00=kKg]/09MkK
00@00=kKg]/000;Nf`04003NfmkK000Wg]/01000g]_Nf`000]kK00<00=kKg]/03=kK00<00=kKg]/0
5mkK000Ig]/00`00g]_Nf`03g]/00`00g]_Nf`0:g]/00`00g]_Nf`1Gg]/00`00g]_Nf`03g]/00`00
g]_Nf`0;g]/00`00g]_Nf`0Vg]/00`00g]_Nf`05g]/00`00g]_Nf`0Vg]/00`00g]_Nf`04g]/00`00
g]_Nf`0:g]/00`00g]_Nf`0Xg]/01000g]_Nf`000]kK00<00=kKg]/0:=kK00D00=kKg]_Nf`0000gN
f`03003NfmkK01ONf`006MkK00<00=kKg]/00mkK00<00=kKg]/01mkK0`00FmkK00<00=kKg]/00mkK
00<00=kKg]/01mkK0`00:]kK00@00=kKg]_Nf`<002[Nf`03003NfmkK00?Nf`03003NfmkK00ONf`<0
02WNf`8000?Nf`04003NfmkK000Xg]/20005g]/00`00g]_Nf`07g]/3000Jg]/001WNf`03003NfmkK
00CNf`03003NfmkK00KNf`03003NfmkK05cNf`03003NfmkK00?Nf`03003NfmkK00KNf`03003NfmkK
02_Nf`04003NfmkK000]g]/00`00g]_Nf`03g]/00`00g]_Nf`06g]/00`00g]_Nf`0[g]/01000g]_N
f`000]kK00<00=kKg]/0:=kK00<00=kKg]/00mkK00<00=kKg]/01]kK00<00=kKg]/06]kK000Gg]/3
0003g]/01000g]_Nf`002=kK00<00=kKg]/0FMkK00@00=kKg]/000;Nf`04003NfmkK0008g]/00`00
g]_Nf`0Xg]/01000g]_Nf`000]kK00<00=kKg]/0:=kK00@00=kKg]/000;Nf`04003NfmkK0008g]/0
0`00g]_Nf`0Xg]/01000g]_Nf`000]kK00@00=kKg]/002ONf`04003NfmkK0002g]/01000g]_Nf`00
2=kK00<00=kKg]/06]kK000Ig]/01000g]_NfmkK10002=kK1000FMkK0P001=kK0P002MkK1000:=kK
0P000mkK1000:=kK0P000mkK10002=kK1000:=kK0P001=kK0P00:MkK0P001=kK0P002MkK10006MkK
003og]^Ag]/00?oNfi7Nf`00omkKTMkK003og]^Ag]/00?oNfi7Nf`003]kKo`00M0003mkK000Gg]/0
0`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/0
0`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/0
0`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/0
0`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/0
0`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/0
0`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`08g]/0
0`00g]_Nf`08g]/00`00g]_Nf`08g]/00`00g]_Nf`0Fg]/002;Nf`03003NfmkK03CNf`03003NfmkK
03CNf`03003NfmkK03CNf`03003NfmkK03CNf`03003NfmkK03CNf`03003NfmkK03CNf`03003NfmkK
027Nf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oN
fcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oN
fcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`<00?oNfcGNf`00
FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00
FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00
FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00
FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`<00?oNfcGNf`00FMkK00<0
0=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<0
0=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<0
0=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<0
0=kKg]/0omkK=MkK001Ig]/3003og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0
omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0
omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0
omkK=MkK001Ig]/00`00g]_Nf`1Qg]/?0034g]/004GNf`8000CNf`03003NfmkK00;Nf`@000GNf`03
003NfmkK053Nfa4000oNfaD00:oNf`00A=kK00@00=kKg]/000SNf`03003NfmkK00KNf`03003NfmkK
04?Nf`d003GNf`P00:ONf`00A=kK00@00=kKg]/000WNf`03003NfmkK00GNf`<003gNf`H004[Nf`L0
0:3Nf`00A=kK00@00=kKg]/000[Nf`03003NfmkK00CNf`03003NfmkK03SNf`D005ONf`L009WNf`00
A=kK00@00=kKg]/000_Nf`03003NfmkK00?Nf`03003NfmkK03CNf`@006?Nf`@009GNf`00A=kK00@0
0=kKg]/000SNf`04003NfmkK0005g]/00`00g]_Nf`0`g]/4001[g]/5002@g]/004GNf`8000[Nf`80
00KNf`03003NfmkK02cNf`@007CNf`@008cNf`00FMkK00<00=kKg]/0:=kK1000O=kK0`00RMkK001I
g]/00`00g]_Nf`0Tg]/40023g]/30026g]/005WNf`03003NfmkK027Nf`<008[Nf`<008?Nf`00FMkK
00<00=kKg]/07]kK0`00T=kK0`00P=kK001Ig]/00`00g]_Nf`0Kg]/3002Fg]/3001mg]/005WNf`03
003NfmkK01SNf`<009cNf`<007[Nf`00FMkK0`005MkK0`00X]kK0P00N=kK001Ig]/00`00g]_Nf`0B
g]/3002Wg]/3001eg]/005WNf`03003NfmkK013Nf`800:gNf`<007;Nf`00FMkK00<00=kKg]/03]kK
0P00/]kK0P00L=kK001Ig]/00`00g]_Nf`0;g]/3002fg]/2001^g]/005WNf`03003NfmkK00WNf`80
0;_Nf`8006cNf`00FMkK00<00=kKg]/01mkK0P00_mkK0P00J]kK001Ig]/00`00g]_Nf`05g]/20033
g]/2001Xg]/005WNf`03003NfmkK00?Nf`800<ONf`8006KNf`00FMkK00@00=kKg]_Nf`800<_Nf`80
06CNf`00FMkK00@00=kKg]/00<oNf`8006;Nf`00FMkK0`00d]kK00<00=kKg]/0GmkK001Hg]/2003E
g]/2001Og]/005ONf`03003Nf`000=ONf`8005gNf`00EMkK0P000]kK00<00=kKg]/0emkK00<00=kK
g]/0F]kK001Cg]/20004g]/00`00g]_Nf`3Hg]/2001Jg]/005;Nf`03003NfmkK00CNf`03003NfmkK
0=[Nf`8005SNf`00D=kK0P001mkK00<00=kKg]/0g=kK00<00=kKg]/0EMkK001?g]/00`00g]_Nf`07
g]/00`00g]_Nf`3Mg]/2001Eg]/004kNf`03003NfmkK00SNf`03003NfmkK0=oNf`8005?Nf`00C=kK
0P002mkK00<00=kKg]/0hMkK00<00=kKg]/0D=kK001;g]/00`00g]_Nf`0;g]/00`00g]_Nf`3Rg]/0
0`00g]_Nf`1?g]/004WNf`8000kNf`03003NfmkK0>?Nf`8004oNf`00B=kK00<00=kKg]/03]kK0`00
iMkK00<00=kKg]/0C=kK0017g]/00`00g]_Nf`0?g]/00`00g]_Nf`3Vg]/00`00g]_Nf`1;g]/004GN
f`8001;Nf`03003NfmkK0>ONf`03003NfmkK04[Nf`00A=kK00<00=kKg]/04]kK00<00=kKg]/0j=kK
0P00B]kK0013g]/00`00g]_Nf`0Cg]/00`00g]_Nf`3Zg]/00`00g]_Nf`17g]/004;Nf`03003NfmkK
01CNf`03003NfmkK0>_Nf`03003NfmkK04KNf`00@=kK0P005mkK00<00=kKg]/0k=kK0P00A]kK000o
g]/00`00g]_Nf`0Gg]/00`00g]_Nf`3^g]/00`00g]_Nf`13g]/003kNf`03003NfmkK01SNf`03003N
fmkK0>oNf`03003NfmkK04;Nf`00?MkK00<00=kKg]/01MkK0P001=kK00<00=kKg]/01=kK00<00=kK
g]/01=kK00<00=kKg]/0l=kK00<00=kKg]/0@MkK000lg]/00`00g]_Nf`05g]/01000g]_Nf`002]kK
00<00=kKg]/01=kK00<00=kKg]/0lMkK00<00=kKg]/0@=kK000kg]/00`00g]_Nf`06g]/01000g]_N
f`001mkK1@001MkK0`00l]kK00<00=kKg]/0?mkK000jg]/00`00g]_Nf`07g]/01000g]_Nf`001mkK
00@00=kKg]/000KNf`03003NfmkK0??Nf`03003NfmkK03kNf`00>=kK0P002]kK00@00=kKg]/000SN
f`03003Nf`0000KNf`03003NfmkK0?CNf`03003NfmkK03gNf`00=mkK00<00=kKg]/02]kK00@00=kK
g]/000WNf`8000KNf`03003NfmkK0?GNf`03003NfmkK03cNf`00=]kK00<00=kKg]/03=kK0P002mkK
00<00=kKg]/01=kK00<00=kKg]/0m]kK00<00=kKg]/0>mkK000eg]/00`00g]_Nf`0Qg]/00`00g]_N
f`3gg]/00`00g]_Nf`0jg]/003CNf`03003NfmkK02;Nf`03003NfmkK0?SNf`03003NfmkK03WNf`00
<mkK00<00=kKg]/08mkK00<00=kKg]/0nMkK00<00=kKg]/0>=kK000bg]/00`00g]_Nf`0Tg]/00`00
g]_Nf`3jg]/00`00g]_Nf`0gg]/0037Nf`03003NfmkK02GNf`03003NfmkK0?_Nf`03003NfmkK03KN
f`00<MkK00<00=kKg]/09MkK00<00=kKg]/0o=kK00<00=kKg]/0=MkK000`g]/00`00g]_Nf`0Vg]/0
0`00g]_Nf`3mg]/00`00g]_Nf`0dg]/002oNf`03003NfmkK02ONf`<00?kNf`03003NfmkK03?Nf`00
;]kK00<00=kKg]/0:=kK00<00=kKg]/0omkK00<00=kKg]/0<]kK000]g]/00`00g]_Nf`0Yg]/00`00
g]_Nf`3og]/1g]/00`00g]_Nf`0ag]/002cNf`03003NfmkK02[Nf`03003NfmkK0?oNf`7Nf`03003N
fmkK037Nf`00:mkK00<00=kKg]/0:mkK00<00=kKg]/0omkK0]kK00<00=kKg]/0<=kK000Zg]/00`00
g]_Nf`0/g]/00`00g]_Nf`3og]/3g]/00`00g]_Nf`0_g]/002[Nf`03003NfmkK02cNf`03003NfmkK
0?oNf`CNf`03003NfmkK02kNf`00:MkK00<00=kKg]/0;MkK00<00=kKg]/0omkK1=kK00<00=kKg]/0
;]kK000Xg]/00`00g]_Nf`0^g]/00`00g]_Nf`3og]/5g]/00`00g]_Nf`0]g]/002ONf`03003NfmkK
02oNf`03003NfmkK0?oNf`KNf`03003NfmkK02cNf`009]kK00<00=kKg]/0<=kK00<00=kKg]/0omkK
1mkK00<00=kKg]/0:mkK000Ug]/00`00g]_Nf`0ag]/3003og]/8g]/00`00g]_Nf`0Zg]/002GNf`03
003NfmkK037Nf`03003NfmkK0?oNf`SNf`03003NfmkK02[Nf`009=kK00<00=kKg]/0<]kK00<00=kK
g]/0omkK2MkK00<00=kKg]/0:MkK000Sg]/00`00g]_Nf`0cg]/00`00g]_Nf`3og]/:g]/00`00g]_N
f`0Xg]/002;Nf`03003NfmkK03CNf`03003NfmkK0?oNf`_Nf`03003NfmkK02ONf`008]kK00<00=kK
g]/0==kK00<00=kKg]/0omkK2mkK00<00=kKg]/09mkK000Qg]/00`00g]_Nf`0eg]/00`00g]_Nf`3o
g]/<g]/00`00g]_Nf`0Vg]/0023Nf`03003NfmkK03KNf`03003NfmkK0?oNf`gNf`03003NfmkK02GN
f`007mkK00<00=kKg]/0=mkK00<00=kKg]/0omkK3]kK00<00=kKg]/09=kK000Og]/00`00g]_Nf`0g
g]/00`00g]_Nf`3og]/>g]/00`00g]_Nf`0Tg]/001kNf`03003NfmkK03SNf`03003NfmkK0?oNf`oN
f`03003NfmkK02?Nf`007MkK00<00=kKg]/0>MkK0`00omkK4=kK00<00=kKg]/08]kK000Lg]/00`00
g]_Nf`0jg]/00`00g]_Nf`3og]/Ag]/00`00g]_Nf`0Qg]/001cNf`03003NfmkK03[Nf`03003NfmkK
0?oNfa7Nf`03003NfmkK027Nf`006mkK00<00=kKg]/0>mkK00<00=kKg]/0omkK4]kK00<00=kKg]/0
8=kK000Jg]/00`00g]_Nf`0lg]/00`00g]_Nf`3og]/Cg]/00`00g]_Nf`0Og]/001WNf`03003NfmkK
03gNf`03003NfmkK0?oNfa?Nf`03003NfmkK01oNf`006MkK00<00=kKg]/0?MkK00<00=kKg]/0omkK
5=kK00<00=kKg]/07]kK000Hg]/00`00g]_Nf`0ng]/00`00g]_Nf`3og]/Eg]/00`00g]_Nf`0Mg]/0
01ONf`03003NfmkK03oNf`03003NfmkK0?oNfaKNf`03003NfmkK01cNf`00FMkK00<00=kKg]/0omkK
5]kK00<00=kKg]/07=kK0015g]/20004g]/00`00g]_Nf`03g]/20006g]/00`00g]_Nf`3og]/Gg]/0
0`00g]_Nf`0Kg]/004CNf`04003NfmkK0008g]/01000g]_Nf`001MkK00<00=kKg]/0omkK6=kK00<0
0=kKg]/06]kK0014g]/01000g]_Nf`002=kK00@00=kKg]/000GNf`<00?oNfaSNf`03003NfmkK01[N
f`00A=kK00@00=kKg]/000SNf`<000KNf`03003NfmkK0?oNfaWNf`03003NfmkK01WNf`00A=kK00@0
0=kKg]/000SNf`03003NfmkK00KNf`03003NfmkK0?oNfa[Nf`03003NfmkK01SNf`00A=kK00@00=kK
g]/000SNf`03003NfmkK00KNf`03003NfmkK0?oNfa_Nf`03003NfmkK01ONf`00AMkK0P002]kK0`00
1MkK00<00=kKg]/0omkK6mkK00<00=kKg]/05mkK001Ig]/00`00g]_Nf`3og]/Lg]/00`00g]_Nf`0F
g]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/e
g]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/3003og]/eg]/005WN
f`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WN
f`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WN
f`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WN
f`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/3003og]/eg]/005WNf`03003N
fmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003N
fmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003N
fmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003N
fmkK0?oNfcGNf`00FMkK0`00omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oN
fcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oN
fcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oN
fcGNf`00AMkK0P001=kK00<00=kKg]/00mkK0P001]kK00<00=kKg]/0omkK=MkK0014g]/01000g]_N
f`002=kK00@00=kKg]/000GNf`03003NfmkK0?oNfcGNf`00A=kK00@00=kKg]/000SNf`04003NfmkK
0005g]/3003og]/eg]/004CNf`04003NfmkK0009g]/20006g]/00`00g]_Nf`3og]/eg]/004CNf`04
003NfmkK0008g]/01000g]_Nf`001MkK00<00=kKg]/0omkK=MkK0014g]/01000g]_Nf`002=kK00@0
0=kKg]/000GNf`03003NfmkK0?oNfcGNf`00AMkK0P002]kK0P001]kK00<00=kKg]/0omkK=MkK001I
g]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001I
g]/00`00g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001I
g]/00`00g]_Nf`3og]/eg]/005WNf`<00?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00
g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00
g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00
g]_Nf`3og]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/3003o
g]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3o
g]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3o
g]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3o
g]/eg]/005WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/3003og]/eg]/0
05WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/0
05WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001Ig]/00`00g]_Nf`3og]/eg]/0
05WNf`03003NfmkK0?oNfcGNf`00FMkK00<00=kKg]/0omkK=MkK001@g]/40005g]/00`00g]_Nf`3o
g]/eg]/005;Nf`03003NfmkK00CNf`03003NfmkK0?oNfcGNf`00D]kK00<00=kKg]/01=kK0`00omkK
=MkK001Bg]/00`00g]_Nf`3og]/lg]/005;Nf`03003NfmkK0?oNfccNf`00D=kK0`00omkK?]kK001B
g]/00`00g]_Nf`3og]/lg]/00001\
\>"],
  ImageRangeCache->{{{153, 552}, {397, 150.812}} -> {8.95257, 0.601553, \
0.0455246, 0.00438455}}],

Cell[BoxData[
    TagBox[
      RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"simp\[Sigma]v2p", "=", 
      RowBox[{"Series", "[", 
        RowBox[{"vis2p", ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["\[Sigma]", "p"], ",", "0", ",", "1"}], "}"}]}], 
        "]"}]}]], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", 
                  FractionBox[
                    RowBox[{
                      SubsuperscriptBox["p", "g", "2"], " ", 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"T", "-", 
                            FractionBox[
                              RowBox[{"m", " ", 
                                RowBox[{"(", 
                                  RowBox[{"c", "-", 
                                    SubscriptBox["x", "g"]}], ")"}]}], 
                              SubscriptBox["p", "g"]], "+", 
                            FractionBox["\[Tau]", "2"]}], ")"}], "2"]}], 
                    RowBox[{"2", " ", 
                      SuperscriptBox["m", "2"], " ", 
                      SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], "-", 
                FractionBox[
                  RowBox[{
                    SubsuperscriptBox["p", "g", "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          SubscriptBox["T", "B"], "-", 
                          FractionBox[
                            RowBox[{"m", " ", 
                              RowBox[{"(", 
                                RowBox[{"c", "-", 
                                  SubscriptBox["x", "g"]}], ")"}]}], 
                            SubscriptBox["p", "g"]], "+", 
                          FractionBox["\[Tau]", "2"]}], ")"}], "2"]}], 
                  RowBox[{"2", " ", 
                    SuperscriptBox["m", "2"], " ", 
                    SubsuperscriptBox["\[Sigma]", "x", "2"]}]], "-", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FractionBox["L", 
                          SubscriptBox["\[Sigma]", "x"]], "-", 
                        FractionBox[
                          RowBox[{
                            SubscriptBox["p", "g"], " ", "\[Tau]"}], 
                          RowBox[{"2", " ", "m", " ", 
                            SubscriptBox["\[Sigma]", "x"]}]]}], ")"}], "2"]}],
                 "-", 
                RowBox[{
                  FractionBox["1", "2"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FractionBox[
                          SubscriptBox["L", "B"], 
                          SubscriptBox["\[Sigma]", "x"]], "-", 
                        FractionBox[
                          RowBox[{
                            SubscriptBox["p", "g"], " ", "\[Tau]"}], 
                          RowBox[{"2", " ", "m", " ", 
                            SubscriptBox["\[Sigma]", "x"]}]]}], ")"}], 
                    "2"]}]}]], " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", 
                SuperscriptBox["P", "2"]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", 
                SubsuperscriptBox["P", "B", "2"]}], ")"}], " ", 
            SubsuperscriptBox["p", "g", "2"], " ", 
            RowBox[{"Re", "[", "\[Eta]", "]"}]}], 
          RowBox[{"16", " ", 
            SuperscriptBox["m", "2"], " ", "\[Pi]", " ", 
            RowBox[{"(", 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{
                        RowBox[{"-", 
                          FractionBox[
                            RowBox[{
                              SubsuperscriptBox["p", "g", "2"], " ", 
                              SuperscriptBox[
                                RowBox[{"(", 
                                  RowBox[{"T", "-", 
                                    FractionBox[
                                      RowBox[{"m", " ", 
                                        RowBox[{"(", 
                                        RowBox[{"c", "+", "L", "-", 
                                        SubscriptBox["x", "g"]}], ")"}]}], 
                                      SubscriptBox["p", "g"]], "+", 
                                    "\[Tau]"}], ")"}], "2"]}], 
                            RowBox[{"2", " ", 
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                        "-", 
                        FractionBox[
                          RowBox[{
                            SubsuperscriptBox["p", "g", "2"], " ", 
                            SuperscriptBox[
                              RowBox[{"(", 
                                RowBox[{
                                  SubscriptBox["T", "B"], "-", 
                                  FractionBox[
                                    RowBox[{"m", " ", 
                                      RowBox[{"(", 
                                        RowBox[{"c", "+", 
                                        SubscriptBox["L", "B"], "-", 
                                        SubscriptBox["x", "g"]}], ")"}]}], 
                                    SubscriptBox["p", "g"]], "+", "\[Tau]"}], 
                                ")"}], "2"]}], 
                          RowBox[{"2", " ", 
                            SuperscriptBox["m", "2"], " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"1", "-", "P"}], ")"}], "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"1", "-", 
                          SubscriptBox["P", "B"]}], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "g", "2"]}], 
                  RowBox[{"32", " ", 
                    SuperscriptBox["m", "2"], " ", "\[Pi]", " ", 
                    SubsuperscriptBox["\[Sigma]", "x", "2"]}]], "+", 
                FractionBox[
                  RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{
                        RowBox[{"-", 
                          FractionBox[
                            RowBox[{
                              SubsuperscriptBox["p", "g", "2"], " ", 
                              SuperscriptBox[
                                RowBox[{"(", 
                                  RowBox[{"T", "-", 
                                    FractionBox[
                                      RowBox[{"m", " ", 
                                        RowBox[{"(", 
                                        RowBox[{"c", "-", "L", "-", 
                                        SubscriptBox["x", "g"]}], ")"}]}], 
                                      SubscriptBox["p", "g"]]}], ")"}], 
                                "2"]}], 
                            RowBox[{"2", " ", 
                              SuperscriptBox["m", "2"], " ", 
                              SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], 
                        "-", 
                        FractionBox[
                          RowBox[{
                            SubsuperscriptBox["p", "g", "2"], " ", 
                            SuperscriptBox[
                              RowBox[{"(", 
                                RowBox[{
                                  SubscriptBox["T", "B"], "-", 
                                  FractionBox[
                                    RowBox[{"m", " ", 
                                      RowBox[{"(", 
                                        RowBox[{"c", "-", 
                                        SubscriptBox["L", "B"], "-", 
                                        SubscriptBox["x", "g"]}], ")"}]}], 
                                    SubscriptBox["p", "g"]]}], ")"}], "2"]}], 
                          
                          RowBox[{"2", " ", 
                            SuperscriptBox["m", "2"], " ", 
                            SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}]], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"1", "+", "P"}], ")"}], "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"1", "+", 
                          SubscriptBox["P", "B"]}], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "g", "2"]}], 
                  RowBox[{"32", " ", 
                    SuperscriptBox["m", "2"], " ", "\[Pi]", " ", 
                    SubsuperscriptBox["\[Sigma]", "x", "2"]}]]}], ")"}], " ", 
            
            SubsuperscriptBox["\[Sigma]", "x", "2"]}]], "+", 
        InterpretationBox[
          SuperscriptBox[
            RowBox[{"O", "[", 
              SubscriptBox["\[Sigma]", "p"], "]"}], "2"],
          
          SeriesData[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]p, 0, {},
             0, 2, 1],
          Editable->False]}],
      SeriesData[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]p, 0, {
        Times[ 
          Rational[ 1, 16], 
          Power[ E, 
            Plus[ 
              Times[ 
                Rational[ -1, 2], 
                Power[ m, -2], 
                Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x, -2], 
                
                Power[ 
                  Plus[ T, 
                    Times[ -1, m, 
                      Power[ p\[UnderBracket]Subscript\[UnderBracket]g, -1], 
                      Plus[ c, 
                        
                        Times[ -1, 
                          x\[UnderBracket]Subscript\[UnderBracket]g]]], 
                    Times[ 
                      Rational[ 1, 2], \[Tau]]], 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ m, -2], 
                Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x, -2], 
                
                Power[ 
                  Plus[ T\[UnderBracket]Subscript\[UnderBracket]B, 
                    Times[ -1, m, 
                      Power[ p\[UnderBracket]Subscript\[UnderBracket]g, -1], 
                      Plus[ c, 
                        
                        Times[ -1, 
                          x\[UnderBracket]Subscript\[UnderBracket]g]]], 
                    Times[ 
                      Rational[ 1, 2], \[Tau]]], 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ 
                  Plus[ 
                    Times[ L, 
                      
                      Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x,\
 -1]], 
                    Times[ 
                      Rational[ -1, 2], 
                      Power[ m, -1], 
                      p\[UnderBracket]Subscript\[UnderBracket]g, 
                      
                      Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x,\
 -1], \[Tau]]], 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ 
                  Plus[ 
                    Times[ L\[UnderBracket]Subscript\[UnderBracket]B, 
                      
                      Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x,\
 -1]], 
                    Times[ 
                      Rational[ -1, 2], 
                      Power[ m, -1], 
                      p\[UnderBracket]Subscript\[UnderBracket]g, 
                      
                      Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x,\
 -1], \[Tau]]], 2]]]], 
          Power[ m, -2], 
          Plus[ 1, 
            Times[ -1, 
              Power[ P, 2]]], 
          Power[ Pi, -1], 
          Plus[ 1, 
            Times[ -1, 
              Power[ P\[UnderBracket]Subscript\[UnderBracket]B, 2]]], 
          Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
          Power[ 
            Plus[ 
              Times[ 
                Rational[ 1, 32], 
                Power[ E, 
                  Plus[ 
                    Times[ 
                      Rational[ -1, 2], 
                      Power[ m, -2], 
                      Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                      
                      Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x,\
 -2], 
                      Power[ 
                        Plus[ T, 
                          Times[ -1, m, 
                            Power[ 
                            p\[UnderBracket]Subscript\[UnderBracket]g, -1], 
                            Plus[ c, L, 
                              
                              Times[ -1, 
                                x\[UnderBracket]Subscript\[UnderBracket]g]]], \
\[Tau]], 2]], 
                    Times[ 
                      Rational[ -1, 2], 
                      Power[ m, -2], 
                      Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                      
                      Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x,\
 -2], 
                      Power[ 
                        Plus[ T\[UnderBracket]Subscript\[UnderBracket]B, 
                          Times[ -1, m, 
                            Power[ 
                            p\[UnderBracket]Subscript\[UnderBracket]g, -1], 
                            Plus[ 
                            c, L\[UnderBracket]Subscript\[UnderBracket]B, 
                              
                              Times[ -1, 
                                x\[UnderBracket]Subscript\[UnderBracket]g]]], \
\[Tau]], 2]]]], 
                Power[ m, -2], 
                Power[ 
                  Plus[ 1, 
                    Times[ -1, P]], 2], 
                Power[ Pi, -1], 
                Power[ 
                  Plus[ 1, 
                    Times[ -1, P\[UnderBracket]Subscript\[UnderBracket]B]], 
                  2], 
                Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x, -2]],
               
              Times[ 
                Rational[ 1, 32], 
                Power[ E, 
                  Plus[ 
                    Times[ 
                      Rational[ -1, 2], 
                      Power[ m, -2], 
                      Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                      Power[ 
                        Plus[ T, 
                          Times[ -1, m, 
                            Power[ 
                            p\[UnderBracket]Subscript\[UnderBracket]g, -1], 
                            Plus[ c, 
                              Times[ -1, L], 
                              
                              Times[ -1, 
                                x\[UnderBracket]Subscript\[UnderBracket]g]]]],
                         2], 
                      
                      Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x,\
 -2]], 
                    Times[ 
                      Rational[ -1, 2], 
                      Power[ m, -2], 
                      Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                      Power[ 
                        Plus[ T\[UnderBracket]Subscript\[UnderBracket]B, 
                          Times[ -1, m, 
                            Power[ 
                            p\[UnderBracket]Subscript\[UnderBracket]g, -1], 
                            Plus[ c, 
                              
                              Times[ -1, 
                                L\[UnderBracket]Subscript\[UnderBracket]B], 
                              
                              Times[ -1, 
                                x\[UnderBracket]Subscript\[UnderBracket]g]]]],
                         2], 
                      
                      Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x,\
 -2]]]], 
                Power[ m, -2], 
                Power[ 
                  Plus[ 1, P], 2], 
                Power[ Pi, -1], 
                Power[ 
                  Plus[ 1, P\[UnderBracket]Subscript\[UnderBracket]B], 2], 
                Power[ p\[UnderBracket]Subscript\[UnderBracket]g, 2], 
                
                Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x, \
-2]]], -1], 
          Power[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x, -2], 
          Re[ \[Eta]]]}, 0, 2, 1],
      Editable->False]], "Output",
  CellLabel->"Out[68]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
WindowSize->{1593, 1166},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "alv"}, \
"mapping-old-new-vars-countrates.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Assumptions -> {
Greater[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]p, 0], 
Greater[ \[Sigma]\[UnderBracket]Subscript\[UnderBracket]x, 0], 
Greater[ m, 0], 
Greater[ T, 0], 
Greater[ \[Tau], 0], 
Greater[ p\[UnderBracket]Subscript\[UnderBracket]g, 0]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style. Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    CellFrameLabelMargins->6,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{18, 10}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{0.95, 12},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{25, 10}, {15, 30}},
    CellFrameMargins->{{0, 0}, {0, 15}},
    FontSize->54],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 4}, {0, 0}},
    CellFrameMargins->4,
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 10}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{25, 10}, {25, 10}},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Printout"],
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->5,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 5}},
    CellMargins->{{25, 10}, {40, 20}},
    FontSize->27],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellMargins->{{18, 4}, {10, 30}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{25, 10}, {30, 22}},
    FontSize->27],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{18, 4}, {10, 30}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 50}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{25, 10}, {25, 25}},
    FontSize->21],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 50}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{25, 10}, {10, 20}},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 4}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{25, 10}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 55}, {5, 4}},
    PageBreakAbove->False,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Presentation"],
    CellMargins->{{75, 55}, {5, 5}},
    FontSize->14],
  
  Cell[StyleData["Caption", "Printout"],
    Hyphenation->True,
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Inert"],
    StyleMenuListing->None,
    Background->RGBColor[0.870588, 0.905882, 0.972549]],
  
  Cell[StyleData["Inert", "Printout"],
    StyleMenuListing->None,
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{1, 1}, {0, 1}},
    CellMargins->{{55, 10}, {0, 10}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Input", "Presentation"],
    CellFrame->{{2, 2}, {0, 2}},
    CellMargins->{{75, 10}, {0, 10}},
    CellFrameMargins->12,
    FontSize->18],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInput", "Presentation"],
    CellMargins->{{8, 8}, {4, 4}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{1, 1}, {1, 0}},
    CellMargins->{{55, 10}, {10, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Output", "Presentation"],
    CellFrame->{{2, 2}, {2, 0}},
    CellMargins->{{75, 10}, {15, 0}},
    CellFrameMargins->12,
    FontSize->18],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 0}},
    ShowCellLabel->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellFrame->1,
    CellMargins->{{55, 10}, {0, 10}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellFrame->2,
    CellMargins->{{75, 10}, {0, 15}},
    CellFrameMargins->12,
    FontSize->18],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellFrame->{{1, 1}, {0, 0}},
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, 10}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["Message", "Presentation"],
    CellFrame->{{2, 2}, {0, 0}},
    CellMargins->{{75, 10}, {0, 0}},
    FontSize->15],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, 26}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    Background->GrayLevel[0.700008]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{75, 34}, {0, 8}},
    CellFrameMargins->12,
    FontSize->18],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellFrame->{{1, 1}, {0, 0}},
    CellMargins->{{55, 10}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellFrame->{{2, 2}, {0, 0}},
    CellMargins->{{75, 10}, {0, 0}},
    CellFrameMargins->12,
    FontSize->18],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{20, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{25, 10}, {4, 30}},
    FontSize->21],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{18, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    CellMargins->{{25, 10}, {15, 4}},
    FontSize->18],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellFrame->False,
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Abstract", "Presentation"],
    CellMargins->{{60, 75}, {4, 35}},
    FontSize->18],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    TextJustification->1,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Presentation"],
    CellMargins->{{18, 40}, {2, 2}},
    FontSize->18],
  
  Cell[StyleData["Reference", "Printout"],
    Hyphenation->True,
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 1}, {0, 0}},
    CellMargins->{{55, Inherited}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CellFrame->{{2, 2}, {0, 0}},
    CellMargins->{{75, 10}, {0, 0}},
    CellFrameMargins->12,
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{55, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"]],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{18, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{10, 10}, {10, 12}},
    FontSize->36],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {5, 10}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 5}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {2, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}], FontFamily -> 
            "Helvetica", FontSize -> 10, FontWeight -> "Bold"]}, {
        None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{80, 10}, {2, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}], FontFamily -> 
            "Helvetica", FontSize -> 16, FontWeight -> "Bold"]}, {
        None, None}},
    FontSize->18],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}], FontFamily -> 
            "Helvetica", FontSize -> 8, FontWeight -> "Bold"]}, {
        None, None}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontFamily -> "Helvetica", 
            FontSize -> 10, FontWeight -> "Bold"], None}},
    TextAlignment->Left,
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{80, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontFamily -> "Helvetica", 
            FontSize -> 16, FontWeight -> "Bold"], None}},
    TextAlignment->Left,
    FontSize->18],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontFamily -> "Helvetica", 
            FontSize -> 8, FontWeight -> "Bold"], None}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontFamily -> "Helvetica", 
            FontSize -> 10, FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{80, 145}, {10, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontFamily -> "Helvetica", 
            FontSize -> 16, FontWeight -> "Bold"], None}},
    FontSize->18],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontFamily -> "Helvetica", 
            FontSize -> 8, FontWeight -> "Bold"], None}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{80, 10}, {5, 20}},
    FontSize->18],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{80, 10}, {10, 10}},
    FontSize->18],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{25, 10}, {10, 6}},
    FontSize->18],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["Footer"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 149, 3, 37, "Subtitle"],
Cell[1928, 58, 145, 4, 48, "Input"],
Cell[2076, 64, 181, 4, 48, "Input"],
Cell[2260, 70, 145, 3, 31, "Text"],
Cell[2408, 75, 1166, 29, 51, "Input"],
Cell[3577, 106, 438, 13, 96, "Input"],
Cell[4018, 121, 663, 15, 49, "Text"],
Cell[4684, 138, 1070, 32, 94, "Input"],
Cell[5757, 172, 94, 3, 31, "Text"],
Cell[5854, 177, 2791, 80, 116, "Input"],
Cell[8648, 259, 73, 0, 31, "Text"],
Cell[8724, 261, 3878, 107, 184, "Input"],
Cell[12605, 370, 4334, 114, 200, "Input"],
Cell[16942, 486, 63, 0, 33, "Text"],
Cell[17008, 488, 26, 0, 31, "Text"],
Cell[17037, 490, 1571, 48, 89, "Input"],
Cell[18611, 540, 32, 0, 31, "Text"],
Cell[18646, 542, 1915, 52, 206, "Input"],
Cell[20564, 596, 28, 0, 31, "Text"],
Cell[20595, 598, 1811, 54, 85, "Input"],
Cell[22409, 654, 55, 0, 31, "Text"],
Cell[22467, 656, 3085, 88, 138, "Input"],
Cell[25555, 746, 225, 4, 31, "Text"],
Cell[25783, 752, 1918, 51, 116, "Input"],
Cell[27704, 805, 330, 6, 54, "Text"],

Cell[CellGroupData[{
Cell[28059, 815, 2215, 57, 108, "Input"],
Cell[30277, 874, 36588, 769, 621, "Output"]
}, Open  ]],
Cell[66880, 1646, 117, 3, 31, "Text"],
Cell[67000, 1651, 5431, 139, 222, "Input"],
Cell[72434, 1792, 42, 0, 31, "Text"],
Cell[72479, 1794, 667, 19, 48, "Input"],

Cell[CellGroupData[{
Cell[73171, 1817, 2973, 73, 106, "Input"],
Cell[76147, 1892, 1014, 26, 48, "Output"]
}, Open  ]],
Cell[77176, 1921, 88, 3, 31, "Text"],

Cell[CellGroupData[{
Cell[77289, 1928, 533, 14, 48, "Input"],
Cell[77825, 1944, 245, 7, 48, "Output"]
}, Open  ]],
Cell[78085, 1954, 802, 22, 88, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78924, 1981, 44, 0, 37, "Subtitle"],
Cell[78971, 1983, 156, 3, 31, "Text"],
Cell[79130, 1988, 450, 12, 76, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79617, 2005, 44, 0, 37, "Subtitle"],
Cell[79664, 2007, 87, 3, 31, "Text"],
Cell[79754, 2012, 1184, 29, 69, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80975, 2046, 44, 0, 88, "Title"],
Cell[81022, 2048, 32, 0, 37, "Subtitle"],
Cell[81057, 2050, 170, 5, 48, "Input"],

Cell[CellGroupData[{
Cell[81252, 2059, 479, 13, 48, "Input"],
Cell[81734, 2074, 20927, 443, 360, "Output"]
}, Open  ]],
Cell[102676, 2520, 663, 18, 48, "Input"],

Cell[CellGroupData[{
Cell[103364, 2542, 346, 9, 51, "Input"],
Cell[103713, 2553, 8437, 193, 110, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112187, 2751, 525, 13, 51, "Input"],
Cell[112715, 2766, 1489, 41, 91, "Output"]
}, Open  ]],
Cell[114219, 2810, 512, 13, 51, "Input"],

Cell[CellGroupData[{
Cell[114756, 2827, 33, 0, 37, "Subtitle"],
Cell[114792, 2829, 49, 0, 31, "Text"],
Cell[114844, 2831, 1372, 35, 80, "Input"],
Cell[116219, 2868, 1576, 42, 78, "Text"],

Cell[CellGroupData[{
Cell[117820, 2914, 1788, 45, 71, "Input"],
Cell[119611, 2961, 15970, 448, 264, 4083, 296, "GraphicsData", "PostScript", \
"Graphics"],
Cell[135584, 3411, 174, 5, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135795, 3421, 285, 8, 51, "Input"],
Cell[136083, 3431, 16782, 378, 152, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

